@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -39,48 +34,49 @@ class CControllerHostEdit extends CController {
 
 	protected function checkInput(): bool {
 		$fields = [
-			'hostid'			=> 'db hosts.hostid',
-			'groupids'			=> 'array_db hosts_groups.groupid',
-			'clone'				=> 'in 1',
-			'full_clone'		=> 'in 1',
-			'host'				=> 'db hosts.host',
-			'visiblename'		=> 'db hosts.name',
-			'description'		=> 'db hosts.description',
-			'status'			=> 'db hosts.status|in '.implode(',', [HOST_STATUS_MONITORED,
-										HOST_STATUS_NOT_MONITORED
-									]),
-			'proxy_hostid'		=> 'db hosts.proxy_hostid',
-			'interfaces'		=> 'array',
-			'mainInterfaces'	=> 'array',
-			'groups'			=> 'array',
-			'tags'				=> 'array',
-			'templates'			=> 'array_db hosts.hostid',
-			'add_templates'		=> 'array_db hosts.hostid',
-			'ipmi_authtype'		=> 'in '.implode(',', [IPMI_AUTHTYPE_DEFAULT, IPMI_AUTHTYPE_NONE, IPMI_AUTHTYPE_MD2,
-										IPMI_AUTHTYPE_MD5, IPMI_AUTHTYPE_STRAIGHT, IPMI_AUTHTYPE_OEM,
-										IPMI_AUTHTYPE_RMCP_PLUS
-									]),
-			'ipmi_privilege'	=> 'in '.implode(',', [IPMI_PRIVILEGE_CALLBACK, IPMI_PRIVILEGE_USER,
-										IPMI_PRIVILEGE_OPERATOR, IPMI_PRIVILEGE_ADMIN, IPMI_PRIVILEGE_OEM
-									]),
-			'ipmi_username'		=> 'db hosts.ipmi_username',
-			'ipmi_password'		=> 'db hosts.ipmi_password',
+			'hostid'				=> 'db hosts.hostid',
+			'groupids'				=> 'array_db hosts_groups.groupid',
+			'clone'					=> 'in 1',
+			'host'					=> 'db hosts.host',
+			'visiblename'			=> 'db hosts.name',
+			'description'			=> 'db hosts.description',
+			'status'				=> 'db hosts.status|in '.implode(',', [HOST_STATUS_MONITORED,
+											HOST_STATUS_NOT_MONITORED
+										]),
+			'monitored_by'			=> 'db hosts.monitored_by|in '.implode(',', [ZBX_MONITORED_BY_SERVER, ZBX_MONITORED_BY_PROXY, ZBX_MONITORED_BY_PROXY_GROUP]),
+			'proxyid'				=> 'db hosts.proxyid',
+			'proxy_groupid'			=> 'db hosts.proxy_groupid',
+			'interfaces'			=> 'array',
+			'mainInterfaces'		=> 'array',
+			'groups'				=> 'array',
+			'tags'					=> 'array',
+			'templates'				=> 'array_db hosts.hostid',
+			'add_templates'			=> 'array_db hosts.hostid',
+			'ipmi_authtype'			=> 'in '.implode(',', [IPMI_AUTHTYPE_DEFAULT, IPMI_AUTHTYPE_NONE, IPMI_AUTHTYPE_MD2,
+											IPMI_AUTHTYPE_MD5, IPMI_AUTHTYPE_STRAIGHT, IPMI_AUTHTYPE_OEM,
+											IPMI_AUTHTYPE_RMCP_PLUS
+										]),
+			'ipmi_privilege'		=> 'in '.implode(',', [IPMI_PRIVILEGE_CALLBACK, IPMI_PRIVILEGE_USER,
+											IPMI_PRIVILEGE_OPERATOR, IPMI_PRIVILEGE_ADMIN, IPMI_PRIVILEGE_OEM
+										]),
+			'ipmi_username'			=> 'db hosts.ipmi_username',
+			'ipmi_password'			=> 'db hosts.ipmi_password',
 			'show_inherited_macros' => 'in 0,1',
-			'tls_connect'		=> 'db hosts.tls_connect|in '.implode(',', [HOST_ENCRYPTION_NONE, HOST_ENCRYPTION_PSK,
-										HOST_ENCRYPTION_CERTIFICATE
-									]),
-			'tls_accept'		=> 'db hosts.tls_accept|ge 0|le '.
+			'tls_connect'			=> 'db hosts.tls_connect|in '.implode(',', [HOST_ENCRYPTION_NONE,
+											HOST_ENCRYPTION_PSK, HOST_ENCRYPTION_CERTIFICATE
+										]),
+			'tls_accept'			=> 'db hosts.tls_accept|ge 0|le '.
 										(0 | HOST_ENCRYPTION_NONE | HOST_ENCRYPTION_PSK | HOST_ENCRYPTION_CERTIFICATE),
-			'tls_subject'		=> 'db hosts.tls_subject',
-			'tls_issuer'		=> 'db hosts.tls_issuer',
-			'tls_psk_identity'	=> 'db hosts.tls_psk_identity',
-			'tls_psk'			=> 'db hosts.tls_psk',
-			'inventory_mode'	=> 'db host_inventory.inventory_mode|in '.implode(',', [HOST_INVENTORY_DISABLED,
-										HOST_INVENTORY_MANUAL, HOST_INVENTORY_AUTOMATIC
-									]),
-			'host_inventory'	=> 'array',
-			'macros'			=> 'array',
-			'valuemaps'			=> 'array'
+			'tls_subject'			=> 'db hosts.tls_subject',
+			'tls_issuer'			=> 'db hosts.tls_issuer',
+			'tls_psk_identity'		=> 'db hosts.tls_psk_identity',
+			'tls_psk'				=> 'db hosts.tls_psk',
+			'inventory_mode'		=> 'db host_inventory.inventory_mode|in '.implode(',', [HOST_INVENTORY_DISABLED,
+											HOST_INVENTORY_MANUAL, HOST_INVENTORY_AUTOMATIC
+										]),
+			'host_inventory'		=> 'array',
+			'macros'				=> 'array',
+			'valuemaps'				=> 'array'
 		];
 
 		$ret = ($this->validateInput($fields) && $this->checkCloneSourceHostId());
@@ -98,7 +94,7 @@ class CControllerHostEdit extends CController {
 	 * @return bool
 	 */
 	protected function checkCloneSourceHostId(): bool {
-		if ($this->hasInput('clone') || $this->hasInput('full_clone')) {
+		if ($this->hasInput('clone')) {
 			return $this->hasInput('hostid');
 		}
 
@@ -130,19 +126,20 @@ class CControllerHostEdit extends CController {
 		$clone_hostid = null;
 
 		if ($this->hasInput('hostid')) {
-			if ($this->hasInput('full_clone') || $this->hasInput('clone')) {
+			if ($this->hasInput('clone')) {
 				$clone_hostid = $this->getInput('hostid');
 				$this->host = ['hostid' => null];
 			}
 			else {
 				$hosts = API::Host()->get([
-					'output' => ['hostid', 'host', 'name', 'status', 'description', 'proxy_hostid', 'ipmi_authtype',
-						'ipmi_privilege', 'ipmi_username', 'ipmi_password', 'tls_connect', 'tls_accept', 'tls_issuer',
-						'tls_subject', 'flags', 'inventory_mode'
+					'output' => ['hostid', 'host', 'name', 'monitored_by', 'proxyid', 'proxy_groupid',
+						'assigned_proxyid', 'status', 'description', 'ipmi_authtype', 'ipmi_privilege', 'ipmi_username',
+						'ipmi_password', 'tls_connect', 'tls_accept', 'tls_issuer', 'tls_subject', 'flags',
+						'inventory_mode'
 					],
 					'selectDiscoveryRule' => ['itemid', 'name', 'parent_hostid'],
 					'selectHostGroups' => ['groupid'],
-					'selectHostDiscovery' => ['parent_hostid'],
+					'selectHostDiscovery' => ['parent_hostid', 'disable_source'],
 					'selectInterfaces' => ['interfaceid', 'type', 'main', 'available', 'error', 'details', 'ip', 'dns',
 						'port', 'useip'
 					],
@@ -183,15 +180,17 @@ class CControllerHostEdit extends CController {
 		$data = [
 			'form_action' => $this->host['hostid'] ? 'host.update' : 'host.create',
 			'hostid' => $this->host['hostid'],
-			'full_clone' => $this->hasInput('full_clone') ? 1 : null,
+			'clone' => $this->hasInput('clone') ? 1 : null,
 			'clone_hostid' => $clone_hostid,
 			'host' => $this->host,
 			'is_psk_edit' => $this->hasInput('tls_psk_identity') && $this->hasInput('tls_psk'),
 			'show_inherited_macros' => $this->getInput('show_inherited_macros', 0),
-			'allowed_ui_conf_templates' => CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES),
 			'warnings' => [],
 			'user' => [
-				'debug_mode' => $this->getDebugMode()
+				'debug_mode' => $this->getDebugMode(),
+				'can_edit_templates' => CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES),
+				'can_edit_proxy_groups' => CWebUser::checkAccess(CRoleHelper::UI_ADMINISTRATION_PROXY_GROUPS),
+				'can_edit_proxies' => CWebUser::checkAccess(CRoleHelper::UI_ADMINISTRATION_PROXIES)
 			]
 		];
 
@@ -251,7 +250,7 @@ class CControllerHostEdit extends CController {
 		unset($macro);
 
 		// Reset Secret text macros and set warning for cloned host.
-		if ($this->hasInput('clone') || $this->hasInput('full_clone')) {
+		if ($this->hasInput('clone')) {
 			foreach ($data['host']['macros'] as &$macro) {
 				if (array_key_exists('allow_revert', $macro) && array_key_exists('value', $macro)) {
 					$macro['deny_revert'] = true;
@@ -309,9 +308,34 @@ class CControllerHostEdit extends CController {
 
 		CArrayHelper::sort($data['host']['parentTemplates'], ['name']);
 		$this->extendLinkedTemplates($data['editable_templates']);
-		$this->extendProxies($data['proxies']);
 		$this->extendInventory($data['inventory_items'], $data['inventory_fields']);
 
+		$data['ms_proxy'] = [];
+		$data['ms_proxy_group'] = [];
+		$data['host']['assigned_proxy_name'] = '';
+
+		if ($data['host']['monitored_by'] == ZBX_MONITORED_BY_PROXY) {
+			$data['ms_proxy'] = CArrayHelper::renameObjectsKeys(API::Proxy()->get([
+				'output' => ['proxyid', 'name'],
+				'proxyids' => $data['host']['proxyid']
+			]), ['proxyid' => 'id']);
+		}
+		elseif ($data['host']['monitored_by'] == ZBX_MONITORED_BY_PROXY_GROUP) {
+			$data['ms_proxy_group'] = CArrayHelper::renameObjectsKeys(API::ProxyGroup()->get([
+				'output' => ['proxy_groupid', 'name'],
+				'proxy_groupids' => $data['host']['proxy_groupid']
+			]), ['proxy_groupid' => 'id']);
+
+			if ($data['host']['assigned_proxyid'] != 0) {
+				$db_proxies = API::Proxy()->get([
+					'output' => ['name'],
+					'proxyids' => $data['host']['assigned_proxyid']
+				]);
+
+				$data['host']['assigned_proxy_name'] = $db_proxies[0]['name'];
+			}
+		}
+
 		$data['is_discovery_rule_editable'] = $this->host['discoveryRule']
 			&& API::DiscoveryRule()->get([
 				'output' => [],
@@ -408,34 +432,6 @@ class CControllerHostEdit extends CController {
 			: [];
 	}
 
-	/**
-	 * Function to select data for 'Monitored by proxy' field.
-	 *
-	 * @param array $proxies
-	 *
-	 * @return void
-	 */
-	protected function extendProxies(?array &$proxies): void {
-		if ($this->host['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
-			$proxies = ($this->host['proxy_hostid'] !== '0')
-				? API::Proxy()->get([
-					'output' => ['host', 'proxyid'],
-					'proxyids' => [$this->host['proxy_hostid']],
-					'preservekeys' => true
-				])
-				: [];
-		}
-		else {
-			$proxies = API::Proxy()->get([
-				'output' => ['host', 'proxyid'],
-				'preservekeys' => true
-			]);
-			CArrayHelper::sort($proxies, ['host']);
-		}
-
-		$proxies = array_column($proxies, 'host', 'proxyid');
-	}
-
 	/**
 	 * Function to prepare data of inventory fields and find items selected to populate each of inventory fields.
 	 *
@@ -476,7 +472,7 @@ class CControllerHostEdit extends CController {
 	protected function getInputValues(): array {
 		$inputs = [];
 
-		if ($this->hasInput('clone') || $this->hasInput('full_clone')) {
+		if ($this->hasInput('clone')) {
 			$inputs['groups'] = [];
 			foreach ($this->getInput('groups', []) as $group) {
 				if (is_array($group) && array_key_exists('new', $group)) {
@@ -490,10 +486,9 @@ class CControllerHostEdit extends CController {
 			$inputs['name'] = $this->getInput('visiblename', '');
 			$inputs['inventory'] = $this->getInput('host_inventory', []);
 
-			$this->getInputs($inputs, [
-				'host', 'description', 'status', 'proxy_hostid', 'ipmi_authtype', 'ipmi_privilege', 'ipmi_username',
-				'ipmi_password', 'tls_connect', 'tls_accept', 'tls_subject', 'tls_issuer', 'tls_psk_identity',
-				'tls_psk', 'tags', 'inventory_mode', 'host_inventory'
+			$this->getInputs($inputs, ['host', 'monitored_by', 'proxyid', 'proxy_groupid', 'description', 'status',
+				'ipmi_authtype', 'ipmi_privilege', 'ipmi_username', 'ipmi_password', 'tls_connect', 'tls_accept',
+				'tls_subject', 'tls_issuer', 'tls_psk_identity', 'tls_psk', 'tags', 'inventory_mode', 'host_inventory'
 			]);
 
 			$field_add_templates = $this->getInput('add_templates', []);
@@ -569,7 +564,10 @@ class CControllerHostEdit extends CController {
 			'hostid' => null,
 			'name' => '',
 			'host' => '',
-			'proxy_hostid' => '0',
+			'monitored_by' => ZBX_MONITORED_BY_SERVER,
+			'proxyid' => '0',
+			'proxy_groupid' => '0',
+			'assigned_proxyid' => '0',
 			'status' => HOST_STATUS_MONITORED,
 			'ipmi_authtype' => IPMI_AUTHTYPE_DEFAULT,
 			'ipmi_privilege' => IPMI_PRIVILEGE_USER,
