@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -32,20 +27,23 @@ class CControllerMiscConfigUpdate extends CController {
 			'login_block' =>					'required|db config.login_block|time_unit '.implode(':', [30, SEC_PER_HOUR]),
 			'validate_uri_schemes' =>			'required|db config.validate_uri_schemes|in 0,1',
 			'uri_valid_schemes' =>				'db config.uri_valid_schemes',
-			'x_frame_options' =>				'required|db config.x_frame_options|not_empty',
+			'x_frame_header_enabled' =>			'required|in 0,1',
+			'x_frame_options' =>				'db config.x_frame_options',
 			'iframe_sandboxing_enabled' =>		'required|db config.iframe_sandboxing_enabled|in 0,1',
 			'iframe_sandboxing_exceptions' =>	'db config.iframe_sandboxing_exceptions',
-			'socket_timeout' =>					'required|db config.socket_timeout|time_unit '.implode(':', [1, 300]),
-			'connect_timeout' =>				'required|db config.connect_timeout|time_unit '.implode(':', [1, 30]),
-			'media_type_test_timeout' =>		'required|db config.media_type_test_timeout|time_unit '.implode(':', [1, 300]),
-			'script_timeout' =>					'required|db config.script_timeout|time_unit '.implode(':', [1, 300]),
-			'item_test_timeout' =>				'required|db config.item_test_timeout|time_unit '.implode(':', [1, 300]),
-			'report_test_timeout' =>			'required|db config.report_test_timeout|time_unit '.implode(':', [1, 300]),
 			'vault_provider' =>					'db config.vault_provider|in '.ZBX_VAULT_TYPE_HASHICORP.','.ZBX_VAULT_TYPE_CYBERARK
 		];
 
 		$ret = $this->validateInput($fields);
 
+		if ($ret) {
+			if ($this->getInput('x_frame_header_enabled') == 1) {
+				$fields['x_frame_options'] = 'required|not_empty';
+			}
+
+			$ret = $this->validateInput($fields);
+		}
+
 		if (!$ret) {
 			switch ($this->getValidationError()) {
 				case self::VALIDATION_ERROR:
@@ -84,20 +82,11 @@ class CControllerMiscConfigUpdate extends CController {
 			CSettingsHelper::LOGIN_ATTEMPTS => $this->getInput('login_attempts'),
 			CSettingsHelper::LOGIN_BLOCK => $this->getInput('login_block'),
 			CSettingsHelper::VALIDATE_URI_SCHEMES => $this->getInput('validate_uri_schemes'),
-			CSettingsHelper::X_FRAME_OPTIONS => $this->getInput('x_frame_options'),
 			CSettingsHelper::IFRAME_SANDBOXING_ENABLED => $this->getInput('iframe_sandboxing_enabled'),
-			CSettingsHelper::SOCKET_TIMEOUT => $this->getInput('socket_timeout'),
-			CSettingsHelper::CONNECT_TIMEOUT => $this->getInput('connect_timeout'),
-			CSettingsHelper::MEDIA_TYPE_TEST_TIMEOUT => $this->getInput('media_type_test_timeout'),
-			CSettingsHelper::SCRIPT_TIMEOUT => $this->getInput('script_timeout'),
-			CSettingsHelper::ITEM_TEST_TIMEOUT => $this->getInput('item_test_timeout'),
-			CSettingsHelper::SCHEDULED_REPORT_TEST_TIMEOUT => $this->getInput('report_test_timeout'),
 			CSettingsHelper::VAULT_PROVIDER => $this->getInput('vault_provider', ZBX_VAULT_TYPE_HASHICORP)
 		];
 
-		$settings[CSettingsHelper::ALERT_USRGRPID] = $this->hasInput('alert_usrgrpid')
-			? $this->getInput('alert_usrgrpid')
-			: null;
+		$settings[CSettingsHelper::ALERT_USRGRPID] = $this->getInput('alert_usrgrpid', 0);
 
 		if ($settings[CSettingsHelper::VALIDATE_URI_SCHEMES] == 1) {
 			$settings[CSettingsHelper::URI_VALID_SCHEMES] = $this->getInput('uri_valid_schemes',
@@ -105,6 +94,10 @@ class CControllerMiscConfigUpdate extends CController {
 			);
 		}
 
+		$settings[CSettingsHelper::X_FRAME_OPTIONS] = $this->getInput('x_frame_header_enabled') == 1
+			? $this->getInput('x_frame_options')
+			: 'null';
+
 		if ($settings[CSettingsHelper::IFRAME_SANDBOXING_ENABLED] == 1) {
 			$settings[CSettingsHelper::IFRAME_SANDBOXING_EXCEPTIONS] = $this->getInput('iframe_sandboxing_exceptions',
 				DB::getSchema('config')['fields']['iframe_sandboxing_exceptions']['default']
