@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -38,8 +33,8 @@ $host_form = (new CForm())
 	)
 	->addVar('hostid', $data['hostid'])
 	->addVar('clone_hostid', $data['clone_hostid'])
-	->addVar('full_clone', $data['full_clone'])
-	->addItem((new CSubmitButton(null))->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
+	->addVar('clone', $data['clone'])
+	->addItem((new CSubmitButton())->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
 
 // Host tab.
 $discovered_by = null;
@@ -116,13 +111,11 @@ if ($data['host']['parentTemplates']) {
 		->addStyle('width: '.ZBX_TEXTAREA_STANDARD_WIDTH.'px;');
 
 	foreach ($data['host']['parentTemplates'] as $template) {
-		if ($data['allowed_ui_conf_templates']
+		if ($data['user']['can_edit_templates']
 				&& array_key_exists($template['templateid'], $data['editable_templates'])) {
-			$template_link = (new CLink($template['name'],
-				(new CUrl('templates.php'))
-					->setArgument('form','update')
-					->setArgument('templateid', $template['templateid'])
-			))->setTarget('_blank');
+			$template_link = (new CLink($template['name']))
+				->addClass('js-edit-linked-template')
+				->setAttribute('data-templateid', $template['templateid']);
 		}
 		else {
 			$template_link = new CSpan($template['name']);
@@ -144,14 +137,11 @@ if ($data['host']['parentTemplates']) {
 			(new CCol(
 				($template['link_type'] == TEMPLATE_LINK_MANUAL)
 					? new CHorList([
-						(new CSimpleButton(_('Unlink')))
-							->onClick('host_edit.unlinkTemplate(this)')
-							->addClass(ZBX_STYLE_BTN_LINK),
+						(new CButtonLink(_('Unlink')))->onClick('host_edit.unlinkTemplate(this)'),
 						($data['clone_hostid'] === null)
-							? (new CSimpleButton(_('Unlink and clear')))
+							? (new CButtonLink(_('Unlink and clear')))
 								->setAttribute('data-templateid', $template['templateid'])
 								->onClick('host_edit.unlinkAndClearTemplate(this, this.dataset.templateid)')
-								->addClass(ZBX_STYLE_BTN_LINK)
 							: null
 					])
 					: ''
@@ -180,6 +170,12 @@ $templates_field_items[] = (new CMultiSelect([
 	]
 ]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH);
 
+$disabled_by_lld_icon = $data['host']['status'] == HOST_STATUS_NOT_MONITORED
+		&& array_key_exists('hostDiscovery', $data['host']) && $data['host']['hostDiscovery']
+		&& $data['host']['hostDiscovery']['disable_source'] == ZBX_DISABLE_SOURCE_LLD
+	? makeWarningIcon(_('Disabled automatically by an LLD rule.'))
+	: null;
+
 $host_tab
 	->addItem([
 		new CLabel([
@@ -236,8 +232,8 @@ $host_tab
 			$host_is_discovered
 				? null
 				: new CDiv(
-					(new CButton(null, _('Add')))
-						->addClass(ZBX_STYLE_BTN_LINK)
+					(new CButtonLink(_('Add')))
+						->addClass('add-interface')
 						->setMenuPopup([
 							'type' => 'submenu',
 							'data' => [
@@ -257,23 +253,85 @@ $host_tab
 		)
 	])
 	->addItem([
-		new CLabel(_('Monitored by proxy'), 'label-proxy'),
+		new CLabel(_('Monitored by'), 'label-proxy'),
 		new CFormField(
-			(new CSelect('proxy_hostid'))
-				->setValue($data['host']['proxy_hostid'])
-				->setFocusableElementId('label-proxy')
+			(new CRadioButtonList('monitored_by', (int) $data['host']['monitored_by']))
+				->addValue(_('Server'), ZBX_MONITORED_BY_SERVER)
+				->addValue(_('Proxy'), ZBX_MONITORED_BY_PROXY)
+				->addValue(_('Proxy group'), ZBX_MONITORED_BY_PROXY_GROUP)
 				->setReadonly($host_is_discovered)
-				->addOptions(CSelect::createOptionsFromArray([0 => _('(no proxy)')] + $data['proxies']))
+				->setModern()
 		)
 	])
 	->addItem([
-		new CLabel(_('Enabled'), 'status'),
+		(new CFormField(
+			(new CMultiSelect([
+				'name' => 'proxyid',
+				'object_name' => 'proxies',
+				'multiple' => false,
+				'data' => $data['ms_proxy'],
+				'disabled' => $host_is_discovered,
+				'popup' => [
+					'parameters' => [
+						'srctbl' => 'proxies',
+						'srcfld1' => 'proxyid',
+						'srcfld2' => 'name',
+						'dstfrm' => $host_form->getName(),
+						'dstfld1' => 'proxyid'
+					]
+				]
+			]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		))->addClass('js-field-proxy')
+	])
+	->addItem([
+		(new CFormField(
+			(new CMultiSelect([
+				'name' => 'proxy_groupid',
+				'object_name' => 'proxy_groups',
+				'multiple' => false,
+				'data' => $data['ms_proxy_group'],
+				'disabled' => $host_is_discovered,
+				'popup' => [
+					'parameters' => [
+						'srctbl' => 'proxy_groups',
+						'srcfld1' => 'proxy_groupid',
+						'srcfld2' => 'name',
+						'dstfrm' => $host_form->getName(),
+						'dstfld1' => 'proxy_groupid'
+					]
+				]
+			]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		))->addClass('js-field-proxy-group')
+	])
+	->addItem([
+		new CLabel([_('Enabled'), $disabled_by_lld_icon], 'status'),
 		new CFormField(
 			(new CCheckBox('status', HOST_STATUS_MONITORED))
 				->setChecked($data['host']['status'] == HOST_STATUS_MONITORED)
 		)
 	]);
 
+$proxy_name = null;
+
+if ($data['host']['assigned_proxyid'] != 0) {
+	$proxy_name = $data['user']['can_edit_proxies']
+		? (new CLink($data['host']['assigned_proxy_name']))
+			->addClass('js-edit-proxy')
+			->setAttribute('data-proxyid', $data['host']['assigned_proxyid'])
+		: new CSpan($data['host']['assigned_proxy_name']);
+	$proxy_name->addClass('js-proxy-assigned');
+}
+
+$host_tab->addItem([
+	(new CLabel(_('Assigned proxy')))->addClass('js-field-proxy-group-proxy'),
+	(new CFormField([
+		$proxy_name,
+		(new CSpan(_('Proxy is not assigned yet.')))
+			->addClass(ZBX_STYLE_GREY)
+			->addClass('js-proxy-not-assigned')
+	]))->addClass('js-field-proxy-group-proxy')
+]);
+
 $ipmi_tab = (new CFormGrid())
 	->addItem([
 		new CLabel(_('Authentication algorithm'), 'label_ipmi_authtype'),
@@ -325,7 +383,6 @@ $tags_tab = new CPartial('configuration.tags.tab', [
 	'source' => 'host',
 	'tags' => $data['host']['tags'],
 	'with_automatic' => true,
-	'readonly' => false,
 	'tabs_id' => 'host-tabs',
 	'tags_tab_id' => 'host-tags-tab'
 ]);
@@ -384,13 +441,11 @@ foreach ($data['inventory_fields'] as $inventory_no => $inventory_field) {
 	if (array_key_exists($inventory_no, $data['inventory_items'])) {
 		$item_name = $data['inventory_items'][$inventory_no]['name'];
 
-		$link = (new CLink($item_name,
-			(new CUrl('items.php'))
-				->setArgument('form', 'update')
-				->setArgument('itemid', $data['inventory_items'][$inventory_no]['itemid'])
-				->setArgument('context', 'host')
-				->getUrl()
-		))->setTitle(_s('This field is automatically populated by item "%1$s".', $item_name));
+		$link = (new CLink($item_name))
+			->setTitle(_s('This field is automatically populated by item "%1$s".', $item_name))
+			->setAttribute('data-itemid', $data['inventory_items'][$inventory_no]['itemid'])
+			->setAttribute('data-context', 'host')
+			->addClass('js-update-item');
 
 		$inventory_item = (new CSpan([' ', LARR(), ' ', $link]))->addClass('populating_item');
 		$input_field->addClass('linked_to_item');
@@ -502,13 +557,17 @@ $encryption_tab = (new CFormGrid())
 
 // Value mapping tab.
 if (!$host_is_discovered) {
-	$value_mapping_tab = (new CFormList('valuemap-formlist'))
-		->addRow(null, new CPartial('configuration.valuemap', [
+	$value_mapping_tab = (new CFormList('valuemap-formlist'))->addRow(
+		_('Value mapping'),
+		new CPartial('configuration.valuemap', [
 			'source' => 'host',
 			'valuemaps' => $data['host']['valuemaps'],
 			'readonly' => $host_is_discovered,
-			'form' => 'host'
-		]));
+			'form' => 'host',
+			'table_id' => 'valuemap-table',
+			'with_label' => true
+		])
+	);
 }
 
 // main output
@@ -517,7 +576,7 @@ $tabs = (new CTabView(['id' => 'host-tabs']))
 	->addTab('host-tab', _('Host'), $host_tab)
 	->addTab('ipmi-tab', _('IPMI'), $ipmi_tab, TAB_INDICATOR_IPMI)
 	->addTab('host-tags-tab', _('Tags'), $tags_tab, TAB_INDICATOR_TAGS)
-	->addTab('macros-tab', _('Macros'), $macros_tab, TAB_INDICATOR_MACROS)
+	->addTab('macros-tab', _('Macros'), $macros_tab, TAB_INDICATOR_HOST_MACROS)
 	->addTab('inventory-tab', _('Inventory'), $inventory_tab, TAB_INDICATOR_INVENTORY)
 	->addTab('encryption-tab', _('Encryption'), $encryption_tab, TAB_INDICATOR_ENCRYPTION);
 
