@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -28,12 +23,13 @@ $form = (new CForm('post'))
 	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, CCsrfTokenHelper::get('connector')))->removeId())
 	->setId('connector-form')
 	->setName('connector_form')
-	->addItem(getMessages());
+	->addItem(getMessages())
+	->addStyle('display: none;');
 
 // Enable form submitting on Enter.
-$form->addItem((new CSubmitButton(null))->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
+$form->addItem((new CSubmitButton())->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
 
-$connector_tab = (new CFormGrid())
+$form_grid = (new CFormGrid())
 	->addItem([
 		(new CLabel(_('Name'), 'name'))->setAsteriskMark(),
 		new CFormField(
@@ -84,9 +80,7 @@ $connector_tab = (new CFormGrid())
 				->addClass(ZBX_STYLE_TABLE_INITIAL_WIDTH)
 				->setFooter(
 					new CCol(
-						(new CSimpleButton(_('Add')))
-							->addClass(ZBX_STYLE_BTN_LINK)
-							->addClass('element-table-add')
+						(new CButtonLink(_('Add')))->addClass('element-table-add')
 					)
 				),
 			(new CTemplateTag('tag-row-tmpl'))->addItem(
@@ -113,13 +107,49 @@ $connector_tab = (new CFormGrid())
 						->addClass('js-tag-value')
 						->setAttribute('placeholder', _('value'))
 						->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH),
-					(new CSimpleButton(_('Remove')))
-						->addClass(ZBX_STYLE_BTN_LINK)
-						->addClass('element-table-remove')
+					(new CButtonLink(_('Remove')))->addClass('element-table-remove')
 				]))->addClass('form_row')
 			)
 		])
 	)
+	->addItem([
+		(new CLabel(_('Type of information'), 'item_value_types'))
+			->setAsteriskMark()
+			->addClass('js-field-item-value-types'),
+		(new CFormField(
+			(new CCheckBoxList('item_value_types'))
+				->setOptions([
+					[
+						'value' => ZBX_CONNECTOR_ITEM_VALUE_TYPE_UINT64,
+						'label' => _('Numeric (unsigned)'),
+						'checked' => ZBX_CONNECTOR_ITEM_VALUE_TYPE_UINT64 & $data['form']['item_value_type']
+					],
+					[
+						'value' => ZBX_CONNECTOR_ITEM_VALUE_TYPE_FLOAT,
+						'label' => _('Numeric (float)'),
+						'checked' => ZBX_CONNECTOR_ITEM_VALUE_TYPE_FLOAT & $data['form']['item_value_type']
+					],
+					[
+						'value' => ZBX_CONNECTOR_ITEM_VALUE_TYPE_STR,
+						'label' => _('Character'),
+						'checked' => ZBX_CONNECTOR_ITEM_VALUE_TYPE_STR & $data['form']['item_value_type']
+					],
+					[
+						'value' => ZBX_CONNECTOR_ITEM_VALUE_TYPE_LOG,
+						'label' => _('Log'),
+						'checked' => ZBX_CONNECTOR_ITEM_VALUE_TYPE_LOG & $data['form']['item_value_type']
+					],
+					[
+						'value' => ZBX_CONNECTOR_ITEM_VALUE_TYPE_TEXT,
+						'label' => _('Text'),
+						'checked' => ZBX_CONNECTOR_ITEM_VALUE_TYPE_TEXT & $data['form']['item_value_type']
+					]
+				])
+				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+				->setVertical()
+				->setColumns(3)
+		))->addClass('js-field-item-value-types')
+	])
 	->addItem([
 		new CLabel(_('HTTP authentication'), 'authtype-focusable'),
 		new CFormField(
@@ -161,108 +191,110 @@ $connector_tab = (new CFormGrid())
 				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 		))->addClass('js-field-token')
 	])
-	->addItem([
-		new CLabel(_('Advanced configuration'), 'advanced_configuration'),
-		new CFormField(
-			(new CCheckBox('advanced_configuration'))->setChecked($data['form']['advanced_configuration'])
-		)
-	])
-	->addItem([
-		(new CLabel(_('Max records per message'), 'max_records'))
-			->addClass('js-field-max-records')
-			->setAsteriskMark(),
-		(new CFormField([
-			(new CRadioButtonList('max_records_mode', $data['form']['max_records_mode']))
-				->addValue(_('Unlimited'), 0)
-				->addValue(_('Custom'), 1)
-				->setModern()
-				->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-			(new CNumericBox('max_records', $data['form']['max_records'], 10, false, false, false))
-				->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
-				->setAriaRequired()
-		]))->addClass('js-field-max-records')
-	])
-	->addItem([
-		(new CLabel(_('Concurrent sessions'), 'max_senders'))
-			->addClass('js-field-max-senders')
-			->setAsteriskMark(),
-		(new CFormField(
-			(new CNumericBox('max_senders', $data['form']['max_senders'], 3, false, false, false))
-				->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
-				->setAriaRequired()
-		))->addClass('js-field-max-senders')
-	])
-	->addItem([
-		(new CLabel(_('Attempts'), 'max_attempts'))
-			->addClass('js-field-max-attempts')
-			->setAsteriskMark(),
-		(new CFormField(
-			(new CNumericBox('max_attempts', $data['form']['max_attempts'], 1, false, false, false))
-				->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
-				->setAriaRequired()
-		))->addClass('js-field-max-attempts')
-	])
-	->addItem([
-		(new CLabel(_('Timeout'), 'timeout'))
-			->addClass('js-field-timeout')
-			->setAsteriskMark(),
-		(new CFormField(
-			(new CTextBox('timeout', $data['form']['timeout'], false, DB::getFieldLength('connector', 'timeout')))
-				->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
-				->setAriaRequired()
-		))->addClass('js-field-timeout')
-	])
-	->addItem([
-		(new CLabel(_('HTTP proxy'), 'http_proxy'))->addClass('js-field-http-proxy'),
-		(new CFormField(
-			(new CTextBox('http_proxy', $data['form']['http_proxy'], false,
-				DB::getFieldLength('connector', 'http_proxy')
-			))
-				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-				->setAttribute('placeholder', _('[protocol://][user[:password]@]proxy.example.com[:port]'))
-				->disableAutocomplete()
-		))->addClass('js-field-http-proxy')
-	])
-	->addItem([
-		(new CLabel(_('SSL verify peer'), 'verify_peer'))->addClass('js-field-verify-peer'),
-		(new CFormField(
-			(new CCheckBox('verify_peer', ZBX_HTTP_VERIFY_PEER_ON))
-				->setChecked($data['form']['verify_peer'] == ZBX_HTTP_VERIFY_PEER_ON)
-		))->addClass('js-field-verify-peer')
-	])
-	->addItem([
-		(new CLabel(_('SSL verify host'), 'verify_host'))->addClass('js-field-verify-host'),
-		(new CFormField(
-			(new CCheckBox('verify_host', ZBX_HTTP_VERIFY_HOST_ON))
-				->setChecked($data['form']['verify_host'] == ZBX_HTTP_VERIFY_HOST_ON)
-		))->addClass('js-field-verify-host')
-	])
-	->addItem([
-		(new CLabel(_('SSL certificate file'), 'ssl_cert_file'))->addClass('js-field-ssl-cert-file'),
-		(new CFormField(
-			(new CTextBox('ssl_cert_file', $data['form']['ssl_cert_file'], false,
-				DB::getFieldLength('connector', 'ssl_cert_file')
-			))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-		))->addClass('js-field-ssl-cert-file')
-	])
-	->addItem([
-		(new CLabel(_('SSL key file'), 'ssl_key_file'))->addClass('js-field-ssl-key-file'),
-		(new CFormField(
-			(new CTextBox('ssl_key_file', $data['form']['ssl_key_file'], false,
-				DB::getFieldLength('connector', 'ssl_key_file')
-			))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-		))->addClass('js-field-ssl-key-file')
-	])
-	->addItem([
-		(new CLabel(_('SSL key password'), 'ssl_key_password'))->addClass('js-field-ssl-key-password'),
-		(new CFormField(
-			(new CTextBox('ssl_key_password', $data['form']['ssl_key_password'], false,
-				DB::getFieldLength('connector', 'ssl_key_password')
-			))
-				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-				->disableAutocomplete()
-		))->addClass('js-field-ssl-key-password')
-	])
+	->addItem(
+		(new CFormFieldsetCollapsible(_('Advanced configuration')))
+			->setId('advanced-configuration')
+			->addItem([
+				(new CLabel(_('Max records per message'), 'max_records'))->setAsteriskMark(),
+				new CFormField([
+					(new CRadioButtonList('max_records_mode', $data['form']['max_records_mode']))
+						->addValue(_('Unlimited'), 0)
+						->addValue(_('Custom'), 1)
+						->setModern()
+						->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+					(new CNumericBox('max_records', $data['form']['max_records'], 10, false, false, false))
+						->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
+						->setAriaRequired()
+				])
+			])
+			->addItem([
+				(new CLabel(_('Concurrent sessions'), 'max_senders'))->setAsteriskMark(),
+				new CFormField(
+					(new CNumericBox('max_senders', $data['form']['max_senders'], 3, false, false, false))
+						->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
+						->setAriaRequired()
+				)
+			])
+			->addItem([
+				(new CLabel(_('Attempts'), 'max_attempts'))->setAsteriskMark(),
+				new CFormField(
+					(new CNumericBox('max_attempts', $data['form']['max_attempts'], 1, false, false, false))
+						->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
+						->setAriaRequired()
+				)
+			])
+			->addItem([
+				(new CLabel(_('Attempt interval'), 'attempt_interval'))->setAsteriskMark(),
+				new CFormField(
+					(new CTextBox('attempt_interval', $data['form']['attempt_interval'], false,
+						DB::getFieldLength('connector', 'attempt_interval')
+					))
+						->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
+						->setAriaRequired()
+				)
+			])
+			->addItem([
+				(new CLabel(_('Timeout'), 'timeout'))->setAsteriskMark(),
+				new CFormField(
+					(new CTextBox('timeout', $data['form']['timeout'], false,
+						DB::getFieldLength('connector', 'timeout')
+					))
+						->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+						->setAriaRequired()
+				)
+			])
+			->addItem([
+				new CLabel(_('HTTP proxy'), 'http_proxy'),
+				new CFormField(
+					(new CTextBox('http_proxy', $data['form']['http_proxy'], false,
+						DB::getFieldLength('connector', 'http_proxy')
+					))
+						->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+						->setAttribute('placeholder', _('[protocol://][user[:password]@]proxy.example.com[:port]'))
+						->disableAutocomplete()
+				)
+			])
+			->addItem([
+				new CLabel(_('SSL verify peer'), 'verify_peer'),
+				new CFormField(
+					(new CCheckBox('verify_peer', ZBX_HTTP_VERIFY_PEER_ON))
+						->setChecked($data['form']['verify_peer'] == ZBX_HTTP_VERIFY_PEER_ON)
+				)
+			])
+			->addItem([
+				new CLabel(_('SSL verify host'), 'verify_host'),
+				new CFormField(
+					(new CCheckBox('verify_host', ZBX_HTTP_VERIFY_HOST_ON))
+						->setChecked($data['form']['verify_host'] == ZBX_HTTP_VERIFY_HOST_ON)
+				)
+			])
+			->addItem([
+				new CLabel(_('SSL certificate file'), 'ssl_cert_file'),
+				new CFormField(
+					(new CTextBox('ssl_cert_file', $data['form']['ssl_cert_file'], false,
+						DB::getFieldLength('connector', 'ssl_cert_file')
+					))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+				)
+			])
+			->addItem([
+				new CLabel(_('SSL key file'), 'ssl_key_file'),
+				new CFormField(
+					(new CTextBox('ssl_key_file', $data['form']['ssl_key_file'], false,
+						DB::getFieldLength('connector', 'ssl_key_file')
+					))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+				)
+			])
+			->addItem([
+				new CLabel(_('SSL key password'), 'ssl_key_password'),
+				new CFormField(
+					(new CTextBox('ssl_key_password', $data['form']['ssl_key_password'], false,
+						DB::getFieldLength('connector', 'ssl_key_password')
+					))
+						->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+						->disableAutocomplete()
+				)
+			])
+	)
 	->addItem([
 		new CLabel(_('Description'), 'description'),
 		new CFormField(
@@ -279,10 +311,8 @@ $connector_tab = (new CFormGrid())
 		)
 	]);
 
-$tabs = (new CTabView(['id' => 'connector-tabs']))->addTab('connector-tab', _('Connector'), $connector_tab);
-
 $form
-	->addItem($tabs)
+	->addItem($form_grid)
 	->addItem(
 		(new CScriptTag('
 			connector_edit_popup.init('.json_encode([
