@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 ?>
 
@@ -64,7 +59,8 @@ window.service_edit_popup = new class {
 
 		$problem_tags.dynamicRows({
 			template: '#problem-tag-row-tmpl',
-			rows: problem_tags
+			allow_empty: true,
+			rows: problem_tags,
 		});
 
 		$problem_tags.on('tableupdate.dynamicRows', () => this._update());
@@ -98,7 +94,7 @@ window.service_edit_popup = new class {
 				const $tags = $panel.find('.tags-table');
 
 				$tags
-					.dynamicRows({template: '#tag-row-tmpl'})
+					.dynamicRows({template: '#tag-row-tmpl', allow_empty: true})
 					.on('afteradd.dynamicRows', () => {
 						$tags
 							.find('.<?= ZBX_STYLE_TEXTAREA_FLEXIBLE ?>')
@@ -149,13 +145,13 @@ window.service_edit_popup = new class {
 
 		// Update form field state according to the form data.
 
-		for (const id of ['advanced_configuration', 'propagation_rule', 'algorithm']) {
-			document
-				.getElementById(id)
-				.addEventListener('change', () => this._update());
+		for (const id of ['propagation_rule', 'algorithm']) {
+			document.getElementById(id).addEventListener('change', () => this._update());
 		}
 
 		this._update();
+
+		new CFormFieldsetCollapsible(document.getElementById('advanced-configuration'));
 	}
 
 	_initTemplates() {
@@ -193,7 +189,6 @@ window.service_edit_popup = new class {
 	}
 
 	_update() {
-		const advanced_configuration = document.getElementById('advanced_configuration').checked;
 		const propagation_rule = document.getElementById('propagation_rule').value;
 
 		let has_problem_tags = false;
@@ -216,30 +211,24 @@ window.service_edit_popup = new class {
 		document.getElementById('algorithm-not-applicable-warning').style.display =
 			this.children.size > 0 ? 'none' : '';
 
-		document.getElementById('additional_rules_label').style.display = advanced_configuration ? '' : 'none';
-		document.getElementById('additional_rules_field').style.display = advanced_configuration ? '' : 'none';
-		document.getElementById('status_propagation_rules_label').style.display = advanced_configuration ? '' : 'none';
-		document.getElementById('status_propagation_rules_field').style.display = advanced_configuration ? '' : 'none';
-		document.getElementById('status_propagation_value_field').style.display = advanced_configuration ? '' : 'none';
-		document.getElementById('weight_label').style.display = advanced_configuration ? '' : 'none';
-		document.getElementById('weight_field').style.display = advanced_configuration ? '' : 'none';
-
 		switch (propagation_rule) {
 			case '<?= ZBX_SERVICE_STATUS_PROPAGATION_INCREASE ?>':
 			case '<?= ZBX_SERVICE_STATUS_PROPAGATION_DECREASE ?>':
+				document.getElementById('status_propagation_value_field').style.display = '';
 				document.getElementById('propagation_value_number').style.display = '';
 				document.getElementById('propagation_value_status').style.display = 'none';
 				break;
 
 			case '<?= ZBX_SERVICE_STATUS_PROPAGATION_FIXED ?>':
+				document.getElementById('status_propagation_value_field').style.display = '';
 				document.getElementById('propagation_value_number').style.display = 'none';
 				document.getElementById('propagation_value_status').style.display = '';
 				break;
 
 			default:
+				document.getElementById('status_propagation_value_field').style.display = 'none';
 				document.getElementById('propagation_value_number').style.display = 'none';
 				document.getElementById('propagation_value_status').style.display = 'none';
-				document.getElementById('status_propagation_value_field').style.display = 'none';
 		}
 
 		document.querySelector('#children .js-add').disabled = has_problem_tags;
@@ -446,7 +435,7 @@ window.service_edit_popup = new class {
 		this._post(curl.getUrl(), {serviceids: [this.serviceid]}, (response) => {
 			overlayDialogueDestroy(this.overlay.dialogueid);
 
-			this.dialogue.dispatchEvent(new CustomEvent('dialogue.delete', {detail: response.success}));
+			this.dialogue.dispatchEvent(new CustomEvent('dialogue.submit', {detail: response.success}));
 		});
 	}
 
