@@ -1,31 +1,28 @@
 <?php
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
 /**
  * @var CView $this
+ * @var array $data
  */
 
 if ($data['uncheck']) {
 	uncheckTableRows('dashboard');
 }
+
 $this->addJsFile('layout.mode.js');
 
 $this->enableLayoutModes();
@@ -86,7 +83,8 @@ $table = (new CTableInfo())
 			(new CUrl('zabbix.php'))
 				->setArgument('action', 'dashboard.list')
 				->getUrl())
-	]);
+	])
+	->setPageNavigation($data['paging']);
 
 foreach ($data['dashboards'] as $dashboard) {
 	$tags = [];
@@ -118,11 +116,11 @@ foreach ($data['dashboards'] as $dashboard) {
 
 $form->addItem([
 	$table,
-	$data['paging'],
 	new CActionButtonList('action', 'dashboardids', [
 		'dashboard.delete' => [
 			'name' => _('Delete'),
-			'confirm' => _('Delete selected dashboards?'),
+			'confirm_singular' => _('Delete selected dashboard?'),
+			'confirm_plural' => _('Delete selected dashboards?'),
 			'disabled' => !$data['allowed_edit'],
 			'csrf_token' => CCsrfTokenHelper::get('dashboard')
 		]
