@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -94,7 +89,9 @@ $header = [
 	make_sorting_header(_('Status'), 'status', $data['sort'], $data['sortorder'], $view_url)
 ];
 
-$sla_list = (new CTableInfo())->setHeader($header);
+$sla_list = (new CTableInfo())
+	->setHeader($header)
+	->setPageNavigation($data['paging']);
 
 foreach ($data['slas'] as $slaid => $sla) {
 	if ($data['has_access'][CRoleHelper::ACTIONS_MANAGE_SLA]) {
@@ -146,7 +143,7 @@ foreach ($data['slas'] as $slaid => $sla) {
 		$sla['timezone'] !== ZBX_DEFAULT_TIMEZONE
 			? $sla['timezone']
 			: CTimezoneHelper::getTitle(CTimezoneHelper::getSystemTimezone(), _('System default')),
-		CSlaHelper::getScheduleTag($sla['schedule']),
+		CSlaHelper::getScheduleCaption($sla['schedule']),
 		$sla_report_tag,
 		$status_tag
 	];
@@ -154,7 +151,7 @@ foreach ($data['slas'] as $slaid => $sla) {
 	$sla_list->addRow($row);
 }
 
-$form->addItem([$sla_list, $data['paging']]);
+$form->addItem($sla_list);
 
 if ($data['has_access'][CRoleHelper::ACTIONS_MANAGE_SLA]) {
 	$form->addItem(
@@ -163,27 +160,27 @@ if ($data['has_access'][CRoleHelper::ACTIONS_MANAGE_SLA]) {
 				'content' => (new CSimpleButton(_('Enable')))
 					->addClass(ZBX_STYLE_BTN_ALT)
 					->addClass('js-massenable-sla')
-					->addClass('no-chkbxrange')
+					->addClass('js-no-chkbxrange')
 			],
 			'sla.massdisable' => [
 				'content' => (new CSimpleButton(_('Disable')))
 					->addClass(ZBX_STYLE_BTN_ALT)
 					->addClass('js-massdisable-sla')
-					->addClass('no-chkbxrange')
+					->addClass('js-no-chkbxrange')
 			],
 			'sla.massdelete' => [
 				'content' => (new CSimpleButton(_('Delete')))
 					->addClass(ZBX_STYLE_BTN_ALT)
 					->addClass('js-massdelete-sla')
-					->addClass('no-chkbxrange')
+					->addClass('js-no-chkbxrange')
 			]
 		], 'sla')
 	);
 }
 
-(new CWidget())
+(new CHtmlPage())
 	->setTitle(_('SLA'))
-	->setDocUrl(CDocHelper::getUrl(CDocHelper::SLA_LIST))
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::SERVICES_SLA_LIST))
 	->setControls(
 		(new CTag('nav', true,
 			(new CList())
