@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -97,20 +92,19 @@ class CHostInterface extends CApiService {
 
 		// editable + PERMISSION CHECK
 		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
-			$permission = $options['editable'] ? PERM_READ_WRITE : PERM_READ;
-			$userGroups = getUserGroupsByUserId(self::$userData['userid']);
+			if (self::$userData['ugsetid'] == 0) {
+				return $options['countOutput'] ? '0' : [];
+			}
 
-			$sqlParts['where'][] = 'EXISTS ('.
-				'SELECT NULL'.
-				' FROM hosts_groups hgg'.
-					' JOIN rights r'.
-						' ON r.id=hgg.groupid'.
-							' AND '.dbConditionInt('r.groupid', $userGroups).
-				' WHERE hi.hostid=hgg.hostid'.
-				' GROUP BY hgg.hostid'.
-				' HAVING MIN(r.permission)>'.PERM_DENY.
-					' AND MAX(r.permission)>='.zbx_dbstr($permission).
-				')';
+			$sqlParts['from'][] = 'host_hgset hh';
+			$sqlParts['from'][] = 'permission p';
+			$sqlParts['where'][] = 'hi.hostid=hh.hostid';
+			$sqlParts['where'][] = 'hh.hgsetid=p.hgsetid';
+			$sqlParts['where'][] = 'p.ugsetid='.self::$userData['ugsetid'];
+
+			if ($options['editable']) {
+				$sqlParts['where'][] = 'p.permission='.PERM_READ_WRITE;
+			}
 		}
 
 		// interfaceids
@@ -204,7 +198,7 @@ class CHostInterface extends CApiService {
 		if ($this->outputIsRequested('details', $options['output'])) {
 			foreach ($result as &$value) {
 				$snmp_fields = ['version', 'bulk', 'community', 'securityname', 'securitylevel', 'authpassphrase',
-					'privpassphrase', 'authprotocol', 'privprotocol', 'contextname'
+					'privpassphrase', 'authprotocol', 'privprotocol', 'contextname', 'max_repetitions'
 				];
 
 				$interface_type = $value['type'];
@@ -222,6 +216,10 @@ class CHostInterface extends CApiService {
 						unset($value[$field_name]);
 					}
 
+					if ($details['version'] == SNMP_V1) {
+						unset($details['max_repetitions']);
+					}
+
 					if ($details['version'] == SNMP_V1 || $details['version'] == SNMP_V2C) {
 						foreach (['securityname', 'securitylevel', 'authpassphrase', 'privpassphrase', 'authprotocol',
 								'privprotocol', 'contextname'] as $snmp_field_name) {
@@ -260,7 +258,7 @@ class CHostInterface extends CApiService {
 			$interfaceDBfields = ['interfaceid' => null];
 			$dbInterfaces = $this->get([
 				'output' => API_OUTPUT_EXTEND,
-				'interfaceids' => zbx_objectValues($interfaces, 'interfaceid'),
+				'interfaceids' => array_column($interfaces, 'interfaceid'),
 				'editable' => true,
 				'preservekeys' => true
 			]);
@@ -278,19 +276,13 @@ class CHostInterface extends CApiService {
 
 		$dbHosts = API::Host()->get([
 			'output' => ['host'],
-			'hostids' => zbx_objectValues($interfaces, 'hostid'),
-			'editable' => true,
-			'preservekeys' => true
-		]);
-
-		$dbProxies = API::Proxy()->get([
-			'output' => ['host'],
-			'proxyids' => zbx_objectValues($interfaces, 'hostid'),
+			'hostids' => array_column($interfaces, 'hostid'),
 			'editable' => true,
 			'preservekeys' => true
 		]);
 
 		$check_have_items = [];
+
 		foreach ($interfaces as &$interface) {
 			if (!check_db_fields($interfaceDBfields, $interface)) {
 				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect arguments passed to function.'));
@@ -302,6 +294,7 @@ class CHostInterface extends CApiService {
 				}
 
 				$dbInterface = $dbInterfaces[$interface['interfaceid']];
+
 				if (isset($interface['hostid']) && bccomp($dbInterface['hostid'], $interface['hostid']) != 0) {
 					self::exception(ZBX_API_ERROR_PARAMETERS, _s('Cannot switch host for interface.'));
 				}
@@ -317,13 +310,9 @@ class CHostInterface extends CApiService {
 				$interface = zbx_array_merge($dbInterface, $interface);
 			}
 			else {
-				if (!isset($dbHosts[$interface['hostid']]) && !isset($dbProxies[$interface['hostid']])) {
+				if (!isset($dbHosts[$interface['hostid']])) {
 					self::exception(ZBX_API_ERROR_PARAMETERS, _('No permissions to referred object or it does not exist!'));
 				}
-
-				if (isset($dbProxies[$interface['hostid']])) {
-					$interface['type'] = INTERFACE_TYPE_UNKNOWN;
-				}
 				elseif (!isset($interface['type'])) {
 					self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect arguments passed to function.'));
 				}
@@ -345,13 +334,6 @@ class CHostInterface extends CApiService {
 							$dbHosts[$interface['hostid']]['host']
 					));
 				}
-				elseif ($dbProxies && !empty($dbProxies[$interface['hostid']]['host'])) {
-					self::exception(ZBX_API_ERROR_PARAMETERS,
-						_s('Interface with IP "%1$s" cannot have empty DNS name while having "Use DNS" property on "%2$s".',
-							$interface['ip'],
-							$dbProxies[$interface['hostid']]['host']
-					));
-				}
 				else {
 					self::exception(ZBX_API_ERROR_PARAMETERS, _s('Interface with IP "%1$s" cannot have empty DNS name.', $interface['ip']));
 				}
@@ -405,6 +387,8 @@ class CHostInterface extends CApiService {
 
 			$this->checkSnmpCommunity($interface);
 
+			$this->checkSnmpMaxRepetitions($interface);
+
 			$this->checkSnmpBulk($interface);
 
 			$this->checkSnmpSecurityLevel($interface);
@@ -425,6 +409,7 @@ class CHostInterface extends CApiService {
 	protected function sanitizeSnmpFields(array $interfaces): array {
 		$default_fields = [
 			'community' => '',
+			'max_repetitions' =>  DB::getDefault('interface_snmp', 'max_repetitions'),
 			'securityname' => '',
 			'securitylevel' => DB::getDefault('interface_snmp', 'securitylevel'),
 			'authpassphrase' => '',
@@ -435,6 +420,10 @@ class CHostInterface extends CApiService {
 		];
 
 		foreach ($interfaces as &$interface) {
+			if ($interface['version'] == SNMP_V1) {
+				unset($interface['max_repetitions']);
+			}
+
 			if ($interface['version'] == SNMP_V1 || $interface['version'] == SNMP_V2C) {
 				unset($interface['securityname'], $interface['securitylevel'], $interface['authpassphrase'],
 					$interface['privpassphrase'], $interface['authprotocol'], $interface['privprotocol'],
@@ -793,10 +782,9 @@ class CHostInterface extends CApiService {
 			return;
 		}
 
-		$user_macro_parser = new CUserMacroParser();
+		$dns_parser = new CDnsParser(['usermacros' => true, 'lldmacros' => true, 'macros' => true]);
 
-		if (!preg_match('/^'.ZBX_PREG_DNS_FORMAT.'$/', $interface['dns'])
-				&& $user_macro_parser->parse($interface['dns']) != CParser::PARSE_SUCCESS) {
+		if ($dns_parser->parse($interface['dns']) != CParser::PARSE_SUCCESS) {
 			self::exception(ZBX_API_ERROR_PARAMETERS,
 				_s('Incorrect interface DNS parameter "%1$s" provided.', $interface['dns'])
 			);
@@ -816,14 +804,9 @@ class CHostInterface extends CApiService {
 			return;
 		}
 
-		$user_macro_parser = new CUserMacroParser();
-
-		if (preg_match('/^'.ZBX_PREG_MACRO_NAME_FORMAT.'$/', $interface['ip'])
-				|| $user_macro_parser->parse($interface['ip']) == CParser::PARSE_SUCCESS) {
-			return;
-		}
-
-		$ip_parser = new CIPParser(['v6' => ZBX_HAVE_IPV6]);
+		$ip_parser = new CIPParser(
+			['usermacros' => true, 'lldmacros' => true, 'macros' => true, 'v6' => ZBX_HAVE_IPV6]
+		);
 
 		if ($ip_parser->parse($interface['ip']) != CParser::PARSE_SUCCESS) {
 			self::exception(ZBX_API_ERROR_PARAMETERS, _s('Invalid IP address "%1$s".', $interface['ip']));
@@ -1032,7 +1015,7 @@ class CHostInterface extends CApiService {
 
 	private function checkIfInterfaceHasItems(array $interfaceIds) {
 		$items = API::Item()->get([
-			'output' => ['name'],
+			'output' => ['name_resolved'],
 			'selectHosts' => ['name'],
 			'interfaceids' => $interfaceIds,
 			'preservekeys' => true,
@@ -1044,7 +1027,7 @@ class CHostInterface extends CApiService {
 			$host = reset($item['hosts']);
 
 			self::exception(ZBX_API_ERROR_PARAMETERS,
-				_s('Interface is linked to item "%1$s" on "%2$s".', $item['name'], $host['name']));
+				_s('Interface is linked to item "%1$s" on "%2$s".', $item['name_resolved'], $host['name']));
 		}
 	}
 
@@ -1077,6 +1060,23 @@ class CHostInterface extends CApiService {
 		}
 	}
 
+	/**
+	 * Check SNMP max repetition count.
+	 *
+	 * @param array $interface
+	 *
+	 * @throws APIException if "max_repetitions" value is incorrect.
+	 */
+	protected function checkSnmpMaxRepetitions(array $interface) {
+		if (($interface['details']['version'] == SNMP_V2C || $interface['details']['version'] == SNMP_V3)
+				&& (array_key_exists('max_repetitions', $interface['details'])
+					&& (!is_numeric($interface['details']['max_repetitions'])
+						|| $interface['details']['max_repetitions'] < 1
+						|| $interface['details']['max_repetitions'] > ZBX_MAX_INT32))) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect arguments passed to function.'));
+		}
+	}
+
 	/**
 	 * Validates SNMP interface "bulk" field.
 	 *
@@ -1157,6 +1157,9 @@ class CHostInterface extends CApiService {
 			$sqlParts = $this->addQuerySelect(dbConditionCoalesce('his.version', SNMP_V2C, 'version'), $sqlParts);
 			$sqlParts = $this->addQuerySelect(dbConditionCoalesce('his.bulk', SNMP_BULK_ENABLED, 'bulk'), $sqlParts);
 			$sqlParts = $this->addQuerySelect(dbConditionCoalesce('his.community', '', 'community'), $sqlParts);
+			$sqlParts = $this->addQuerySelect(dbConditionCoalesce('his.max_repetitions', '10', 'max_repetitions'),
+				$sqlParts
+			);
 			$sqlParts = $this->addQuerySelect(dbConditionCoalesce('his.securityname', '', 'securityname'), $sqlParts);
 			$sqlParts = $this->addQuerySelect(
 				dbConditionCoalesce('his.securitylevel', ITEM_SNMPV3_SECURITYLEVEL_NOAUTHNOPRIV, 'securitylevel'),
