@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -180,12 +175,18 @@ class CConfigurationImport {
 		$iconmaps_refs = [];
 		$images_refs = [];
 		$maps_refs = [];
+		$services_refs = [];
+		$slas_refs = [];
+		$users_refs = [];
+		$actions_refs = [];
+		$media_types_refs = [];
 		$template_dashboards_refs = [];
 		$template_macros_refs = [];
 		$host_macros_refs = [];
 		$group_prototypes_refs = [];
 		$host_prototype_macros_refs = [];
 		$proxy_refs = [];
+		$proxy_group_refs = [];
 		$host_prototypes_refs = [];
 		$httptests_refs = [];
 		$httpsteps_refs = [];
@@ -236,6 +237,10 @@ class CConfigurationImport {
 			if ($host['proxy']) {
 				$proxy_refs[$host['proxy']['name']] = [];
 			}
+
+			if ($host['proxy_group']) {
+				$proxy_group_refs[$host['proxy_group']['name']] = [];
+			}
 		}
 
 		foreach ($this->getFormattedItems() as $host => $items) {
@@ -558,6 +563,42 @@ class CConfigurationImport {
 										$graphs_refs[$value['host']][$value['name']] = [];
 									}
 									break;
+
+								case ZBX_WIDGET_FIELD_TYPE_MAP:
+									if (!array_key_exists($value['name'], $maps_refs)) {
+										$maps_refs[$value['name']] = [];
+									}
+									break;
+
+								case ZBX_WIDGET_FIELD_TYPE_SERVICE:
+									if (!array_key_exists($value['name'], $services_refs)) {
+										$services_refs[$value['name']] = [];
+									}
+									break;
+
+								case ZBX_WIDGET_FIELD_TYPE_SLA:
+									if (!array_key_exists($value['name'], $slas_refs)) {
+										$slas_refs[$value['name']] = [];
+									}
+									break;
+
+								case ZBX_WIDGET_FIELD_TYPE_USER:
+									if (!array_key_exists($value['username'], $users_refs)) {
+										$users_refs[$value['username']] = [];
+									}
+									break;
+
+								case ZBX_WIDGET_FIELD_TYPE_ACTION:
+									if (!array_key_exists($value['name'], $actions_refs)) {
+										$actions_refs[$value['name']] = [];
+									}
+									break;
+
+								case ZBX_WIDGET_FIELD_TYPE_MEDIA_TYPE:
+									if (!array_key_exists($value['name'], $media_types_refs)) {
+										$media_types_refs[$value['name']] = [];
+									}
+									break;
 							}
 						}
 					}
@@ -596,12 +637,18 @@ class CConfigurationImport {
 		$this->referencer->addIconmaps($iconmaps_refs);
 		$this->referencer->addImages($images_refs);
 		$this->referencer->addMaps($maps_refs);
+		$this->referencer->addServices($services_refs);
+		$this->referencer->addSlas($slas_refs);
+		$this->referencer->addUsers($users_refs);
+		$this->referencer->addActions($actions_refs);
+		$this->referencer->addMediaTypes($media_types_refs);
 		$this->referencer->addTemplateDashboards($template_dashboards_refs);
 		$this->referencer->addTemplateMacros($template_macros_refs);
 		$this->referencer->addHostMacros($host_macros_refs);
 		$this->referencer->addGroupPrototypes($group_prototypes_refs);
 		$this->referencer->addHostPrototypeMacros($host_prototype_macros_refs);
 		$this->referencer->addProxies($proxy_refs);
+		$this->referencer->addProxyGroups($proxy_group_refs);
 		$this->referencer->addHostPrototypes($host_prototypes_refs);
 		$this->referencer->addHttpTests($httptests_refs);
 		$this->referencer->addHttpSteps($httpsteps_refs);
@@ -773,7 +820,8 @@ class CConfigurationImport {
 
 				$delay_types = [ITEM_TYPE_ZABBIX, ITEM_TYPE_SIMPLE, ITEM_TYPE_INTERNAL, ITEM_TYPE_ZABBIX_ACTIVE,
 					ITEM_TYPE_EXTERNAL, ITEM_TYPE_DB_MONITOR, ITEM_TYPE_IPMI, ITEM_TYPE_SSH, ITEM_TYPE_TELNET,
-					ITEM_TYPE_CALCULATED, ITEM_TYPE_JMX, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP, ITEM_TYPE_SCRIPT
+					ITEM_TYPE_CALCULATED, ITEM_TYPE_JMX, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP, ITEM_TYPE_SCRIPT,
+					ITEM_TYPE_BROWSER
 				];
 
 				if (!in_array($item['type'], $delay_types)) {
@@ -793,7 +841,9 @@ class CConfigurationImport {
 				}
 				unset($item['interface_ref']);
 
-				if (array_key_exists('valuemap', $item) && $item['valuemap']) {
+				$item['valuemapid'] = 0;
+
+				if ($item['valuemap']) {
 					$valuemapid = $this->referencer->findValuemapidByName($hostid, $item['valuemap']['name']);
 
 					if ($valuemapid === null) {
@@ -827,24 +877,6 @@ class CConfigurationImport {
 					unset($item[$master_item_key]);
 				}
 
-				if ($item['type'] == ITEM_TYPE_HTTPAGENT) {
-					$headers = [];
-
-					foreach ($item['headers'] as $header) {
-						$headers[$header['name']] = $header['value'];
-					}
-
-					$item['headers'] = $headers;
-
-					$query_fields = [];
-
-					foreach ($item['query_fields'] as $query_field) {
-						$query_fields[] = [$query_field['name'] => $query_field['value']];
-					}
-
-					$item['query_fields'] = $query_fields;
-				}
-
 				foreach ($item['preprocessing'] as &$preprocessing_step) {
 					$preprocessing_step['params'] = implode("\n", $preprocessing_step['parameters']);
 
@@ -1002,6 +1034,7 @@ class CConfigurationImport {
 
 		$discovery_rules_to_create = [];
 		$discovery_rules_to_update = [];
+		$upd_discovery_rule_hostids = [];
 
 		/*
 		 * It's possible that some LLD rules use master items which are web items. They don't reside in item
@@ -1068,6 +1101,15 @@ class CConfigurationImport {
 					$discovery_rule['graph_prototypes'], $discovery_rule['host_prototypes']
 				);
 
+				$delay_types = [ITEM_TYPE_ZABBIX, ITEM_TYPE_SIMPLE, ITEM_TYPE_INTERNAL, ITEM_TYPE_ZABBIX_ACTIVE,
+					ITEM_TYPE_EXTERNAL, ITEM_TYPE_DB_MONITOR, ITEM_TYPE_IPMI, ITEM_TYPE_SSH, ITEM_TYPE_TELNET,
+					ITEM_TYPE_JMX, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP, ITEM_TYPE_SCRIPT, ITEM_TYPE_BROWSER
+				];
+
+				if (!in_array($discovery_rule['type'], $delay_types)) {
+					unset($discovery_rule['delay']);
+				}
+
 				if (array_key_exists('interface_ref', $discovery_rule) && $discovery_rule['interface_ref']) {
 					$interfaceid = $this->referencer->findInterfaceidByRef($hostid, $discovery_rule['interface_ref']);
 
@@ -1079,24 +1121,7 @@ class CConfigurationImport {
 
 					$discovery_rule['interfaceid'] = $interfaceid;
 				}
-
-				if ($discovery_rule['type'] == ITEM_TYPE_HTTPAGENT) {
-					$headers = [];
-
-					foreach ($discovery_rule['headers'] as $header) {
-						$headers[$header['name']] = $header['value'];
-					}
-
-					$discovery_rule['headers'] = $headers;
-
-					$query_fields = [];
-
-					foreach ($discovery_rule['query_fields'] as $query_field) {
-						$query_fields[] = [$query_field['name'] => $query_field['value']];
-					}
-
-					$discovery_rule['query_fields'] = $query_fields;
-				}
+				unset($discovery_rule['interface_ref']);
 
 				if ($discovery_rule['type'] == ITEM_TYPE_DEPENDENT) {
 					if (!array_key_exists('key', $discovery_rule[$master_item_key])) {
@@ -1148,9 +1173,33 @@ class CConfigurationImport {
 				}
 				unset($preprocessing_step);
 
+				if (array_key_exists('filter', $discovery_rule)) {
+					foreach ($discovery_rule['filter']['conditions'] as &$condition) {
+						if ($discovery_rule['filter']['evaltype'] != CONDITION_EVAL_TYPE_EXPRESSION) {
+							unset($condition['formulaid']);
+						}
+					}
+					unset($condition);
+				}
+
+				foreach ($discovery_rule['overrides'] as &$override) {
+					if (!array_key_exists('filter', $override)) {
+						continue;
+					}
+
+					foreach ($override['filter']['conditions'] as &$condition) {
+						if ($override['filter']['evaltype'] != CONDITION_EVAL_TYPE_EXPRESSION) {
+							unset($condition['formulaid']);
+						}
+					}
+					unset($condition);
+				}
+				unset($override);
+
 				if ($itemid !== null) {
 					$discovery_rule['itemid'] = $itemid;
-					$discovery_rules_to_update[] = $discovery_rule;
+					$discovery_rules_to_update[] = array_diff_key($discovery_rule, array_flip(['hostid']));
+					$upd_discovery_rule_hostids[] = $discovery_rule['hostid'];
 				}
 				else {
 					/*
@@ -1180,7 +1229,9 @@ class CConfigurationImport {
 			API::DiscoveryRule()->update($discovery_rules_to_update);
 
 			foreach ($discovery_rules_to_update as $discovery_rule) {
-				$processed_discovery_rules[$discovery_rule['hostid']][$discovery_rule['key_']] = 1;
+				$hostid = array_shift($upd_discovery_rule_hostids);
+
+				$processed_discovery_rules[$hostid][$discovery_rule['key_']] = 1;
 			}
 		}
 
@@ -1220,7 +1271,8 @@ class CConfigurationImport {
 
 					$delay_types = [ITEM_TYPE_ZABBIX, ITEM_TYPE_SIMPLE, ITEM_TYPE_INTERNAL, ITEM_TYPE_ZABBIX_ACTIVE,
 						ITEM_TYPE_EXTERNAL, ITEM_TYPE_DB_MONITOR, ITEM_TYPE_IPMI, ITEM_TYPE_SSH, ITEM_TYPE_TELNET,
-						ITEM_TYPE_CALCULATED, ITEM_TYPE_JMX, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP, ITEM_TYPE_SCRIPT
+						ITEM_TYPE_CALCULATED, ITEM_TYPE_JMX, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP, ITEM_TYPE_SCRIPT,
+						ITEM_TYPE_BROWSER
 					];
 
 					if (!in_array($item_prototype['type'], $delay_types)) {
@@ -1247,6 +1299,8 @@ class CConfigurationImport {
 					}
 					unset($item_prototype['interface_ref']);
 
+					$item_prototype['valuemapid'] = 0;
+
 					if ($item_prototype['valuemap']) {
 						$valuemapid = $this->referencer->findValuemapidByName($hostid,
 							$item_prototype['valuemap']['name']
@@ -1286,24 +1340,6 @@ class CConfigurationImport {
 						unset($item_prototype[$master_item_key]);
 					}
 
-					if ($item_prototype['type'] == ITEM_TYPE_HTTPAGENT) {
-						$headers = [];
-
-						foreach ($item_prototype['headers'] as $header) {
-							$headers[$header['name']] = $header['value'];
-						}
-
-						$item_prototype['headers'] = $headers;
-
-						$query_fields = [];
-
-						foreach ($item_prototype['query_fields'] as $query_field) {
-							$query_fields[] = [$query_field['name'] => $query_field['value']];
-						}
-
-						$item_prototype['query_fields'] = $query_fields;
-					}
-
 					$item_prototypeid = null;
 
 					if (array_key_exists('uuid', $item_prototype)) {
