@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -134,7 +129,7 @@ class CScreenProblem extends CScreenBase {
 	 * @param int    $filter['age']                   (optional) usable together with 'age_state' and only for
 	 *                                                           TRIGGERS_OPTION_(RECENT|IN)_PROBLEM
 	 * @param array  $filter['severities']            (optional)
-	 * @param int    $filter['unacknowledged']        (optional)
+	 * @param int    $filter['acknowledgement_status'] (optional)
 	 * @param array  $filter['tags']                  (optional)
 	 * @param string $filter['tags'][]['tag']
 	 * @param string $filter['tags'][]['value']
@@ -243,16 +238,8 @@ class CScreenProblem extends CScreenBase {
 					$options['time_from'] = time() - $filter['age'] * SEC_PER_DAY + 1;
 				}
 			}
-			if (array_key_exists('severities', $filter)) {
-				$filter_severities = implode(',', $filter['severities']);
-				$all_severities = implode(',', range(TRIGGER_SEVERITY_NOT_CLASSIFIED, TRIGGER_SEVERITY_COUNT - 1));
-
-				if ($filter_severities !== '' && $filter_severities !== $all_severities) {
-					$options['severities'] = $filter['severities'];
-				}
-			}
-			if (array_key_exists('unacknowledged', $filter) && $filter['unacknowledged']) {
-				$options['acknowledged'] = false;
+			if (array_key_exists('severities', $filter) && $filter['severities']) {
+				$options['severities'] = $filter['severities'];
 			}
 			if (array_key_exists('evaltype', $filter)) {
 				$options['evaltype'] = $filter['evaltype'];
@@ -270,7 +257,26 @@ class CScreenProblem extends CScreenBase {
 			}
 
 			if (array_key_exists('cause_eventid', $filter) && $filter['cause_eventid']) {
-				$options['filter'] = ['cause_eventid' => $filter['cause_eventid']];
+				$options['filter']['cause_eventid'] = $filter['cause_eventid'];
+			}
+
+			if (array_key_exists('acknowledgement_status', $filter)) {
+				switch ($filter['acknowledgement_status']) {
+					case ZBX_ACK_STATUS_UNACK:
+						$options['acknowledged'] = false;
+						break;
+
+					case ZBX_ACK_STATUS_ACK:
+						$options['acknowledged'] = true;
+
+						if (array_key_exists('acknowledged_by_me', $filter) && $filter['acknowledged_by_me'] == 1) {
+							$options += [
+								'action' => ZBX_PROBLEM_UPDATE_ACKNOWLEDGE,
+								'action_userids' => CUser::$userData['userid']
+							];
+						}
+						break;
+				}
 			}
 
 			$problems = ($filter['show'] == TRIGGERS_OPTION_ALL)
@@ -337,13 +343,13 @@ class CScreenProblem extends CScreenBase {
 		$data['problems'] = array_slice($data['problems'], 0, $limit + 1, true);
 
 		if ($show_opdata && $data['triggers']) {
-			$items = API::Item()->get([
-				'output' => ['itemid', 'name', 'value_type', 'units'],
+			$items = CArrayHelper::renameObjectsKeys(API::Item()->get([
+				'output' => ['itemid', 'name_resolved', 'value_type', 'units'],
 				'selectValueMap' => ['mappings'],
 				'triggerids' => array_keys($data['triggers']),
 				'webitems' => true,
 				'preservekeys' => true
-			]);
+			]), ['name_resolved' => 'name']);
 
 			foreach ($data['triggers'] as &$trigger) {
 				foreach ($trigger['functions'] as $function) {
@@ -494,11 +500,11 @@ class CScreenProblem extends CScreenBase {
 	private static function getExDataEvents(array $eventids) {
 		$events = API::Event()->get([
 			'output' => ['eventid', 'r_eventid', 'acknowledged'],
-			'selectTags' => ['tag', 'value'],
-			'select_acknowledges' => ['userid', 'eventid', 'clock', 'message', 'action', 'old_severity', 'new_severity',
+			'selectAcknowledges' => ['userid', 'clock', 'message', 'action', 'old_severity', 'new_severity',
 				'suppress_until', 'taskid'
 			],
 			'selectSuppressionData' => ['maintenanceid', 'userid', 'suppress_until'],
+			'selectTags' => ['tag', 'value'],
 			'source' => EVENT_SOURCE_TRIGGERS,
 			'object' => EVENT_OBJECT_TRIGGER,
 			'eventids' => $eventids,
@@ -551,11 +557,11 @@ class CScreenProblem extends CScreenBase {
 	private static function getExDataProblems(array $eventids) {
 		return API::Problem()->get([
 			'output' => ['eventid', 'r_eventid', 'r_clock', 'r_ns', 'correlationid', 'userid', 'acknowledged'],
-			'selectTags' => ['tag', 'value'],
-			'selectAcknowledges' => ['userid', 'eventid', 'clock', 'message', 'action', 'old_severity', 'new_severity',
+			'selectAcknowledges' => ['userid', 'clock', 'message', 'action', 'old_severity', 'new_severity',
 				'suppress_until', 'taskid'
 			],
 			'selectSuppressionData' => ['maintenanceid', 'userid', 'suppress_until'],
+			'selectTags' => ['tag', 'value'],
 			'source' => EVENT_SOURCE_TRIGGERS,
 			'object' => EVENT_OBJECT_TRIGGER,
 			'eventids' => $eventids,
@@ -642,7 +648,7 @@ class CScreenProblem extends CScreenBase {
 		// get additional data
 		$eventids = array_keys($data['problems']);
 
-		$problems_data = ($filter['show'] == TRIGGERS_OPTION_ALL)
+		$problems_data = $filter['show'] == TRIGGERS_OPTION_ALL
 			? self::getExDataEvents($eventids)
 			: self::getExDataProblems($eventids);
 
@@ -818,6 +824,8 @@ class CScreenProblem extends CScreenBase {
 		$data = self::getData($this->data['filter'], $this->data['limit'], true);
 		$data = self::sortData($data, $this->data['limit'], $this->data['sort'], $this->data['sortorder']);
 
+		$paging = null;
+
 		if ($this->data['action'] === 'problem.view' || $this->data['action'] === 'problem.view.refresh') {
 			$paging = CPagerHelper::paginate($this->page, $data['problems'], ZBX_SORT_UP, $url);
 		}
@@ -987,7 +995,7 @@ class CScreenProblem extends CScreenBase {
 			));
 
 			$this->data['filter']['compact_view']
-				? $header_check_box->addStyle('width: 20px;')
+				? $header_check_box->addStyle('width: 16px;')
 				: $header_check_box->addClass(ZBX_STYLE_CELL_WIDTH);
 
 			$link = $url->getUrl();
@@ -1005,23 +1013,23 @@ class CScreenProblem extends CScreenBase {
 			// There are cause events displayed on page that have symptoms. Maximum column count.
 			if ($do_causes_have_symptoms) {
 				$col_header_1 = (new CColHeader())->addClass(ZBX_STYLE_SECOND_COL);
-				$col_header_2 = (new CColHeader())->addClass(ZBX_STYLE_THIRD_COL);
+				$col_header_2 = new CColHeader();
 
 				if ($this->data['filter']['compact_view']) {
-					$header[] = $col_header_1->addStyle('width: 28px;');
-					$header[] = $col_header_2->addStyle('width: 20px;');
+					$header[] = $col_header_1->addStyle('width: 18px;');
+					$header[] = $col_header_2->addStyle('width: 18px;');
 				}
 				else {
-					$header[] = $col_header_1->addStyle('width: 20px;');
+					$header[] = $col_header_1->addStyle(ZBX_STYLE_CELL_WIDTH);
 					$header[] = $col_header_2->addClass(ZBX_STYLE_CELL_WIDTH);
 				}
 			}
 			// There might be cause events without symptoms or only symptoms.
 			elseif ($symptom_cause_eventids) {
-				$col_header = (new CColHeader())->addClass(ZBX_STYLE_THIRD_COL);
+				$col_header = new CColHeader();
 
 				if ($this->data['filter']['compact_view']) {
-					$header[] = $col_header->addStyle('width: 20px;');
+					$header[] = $col_header->addStyle('width: 16px;');
 				}
 				else {
 					$header[] = $col_header->addClass(ZBX_STYLE_CELL_WIDTH);
@@ -1033,7 +1041,7 @@ class CScreenProblem extends CScreenBase {
 			);
 
 			$this->data['filter']['compact_view']
-				? $header_clock->addStyle('width: 115px;')
+				? $header_clock->addStyle('width: 132px;')
 				: $header_clock->addClass(ZBX_STYLE_CELL_WIDTH);
 
 			if ($show_timeline) {
@@ -1045,6 +1053,8 @@ class CScreenProblem extends CScreenBase {
 				$header[] = $header_clock;
 			}
 
+			$table = (new CTableInfo())->setPageNavigation($paging);
+
 			// Create table.
 			if ($this->data['filter']['compact_view']) {
 				if ($this->data['filter']['show_tags'] == SHOW_TAGS_NONE) {
@@ -1066,47 +1076,45 @@ class CScreenProblem extends CScreenBase {
 					}
 				}
 
-				$table = (new CTableInfo())
-					->setHeader(array_merge($header, [
-						make_sorting_header(_('Severity'), 'severity', $this->data['sort'], $this->data['sortorder'],
-							$link
-						)->addStyle('width: 120px;'),
-						$show_recovery_data ? (new CColHeader(_('Recovery time')))->addStyle('width: 115px;') : null,
-						$show_recovery_data ? (new CColHeader(_('Status')))->addStyle('width: 70px;') : null,
-						(new CColHeader(_('Info')))->addStyle('width: 24px;'),
-						make_sorting_header(_('Host'), 'host', $this->data['sort'], $this->data['sortorder'], $link)
-							->addStyle('width: 42%;'),
-						make_sorting_header(_('Problem'), 'name', $this->data['sort'], $this->data['sortorder'], $link)
-							->addStyle('width: 58%;'),
-						(new CColHeader(_('Duration')))->addStyle('width: 73px;'),
-						(new CColHeader(_('Update')))->addStyle('width: 40px;'),
-						(new CColHeader(_('Actions')))->addStyle('width: 64px;'),
-						$tags_header
-					]))
-						->addClass(ZBX_STYLE_COMPACT_VIEW)
-						->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS);
+				$table->setHeader(array_merge($header, [
+					make_sorting_header(_('Severity'), 'severity', $this->data['sort'], $this->data['sortorder'],
+						$link
+					)->addStyle('width: 120px;'),
+					$show_recovery_data ? (new CColHeader(_('Recovery time')))->addStyle('width: 132px;') : null,
+					$show_recovery_data ? (new CColHeader(_('Status')))->addStyle('width: 70px;') : null,
+					(new CColHeader(_('Info')))->addStyle('width: 24px;'),
+					make_sorting_header(_('Host'), 'host', $this->data['sort'], $this->data['sortorder'], $link)
+						->addStyle('width: 42%;'),
+					make_sorting_header(_('Problem'), 'name', $this->data['sort'], $this->data['sortorder'], $link)
+						->addStyle('width: 58%;'),
+					(new CColHeader(_('Duration')))->addStyle('width: 73px;'),
+					(new CColHeader(_('Update')))->addStyle('width: 40px;'),
+					(new CColHeader(_('Actions')))->addStyle('width: 89px;'),
+					$tags_header
+				]))
+					->addClass(ZBX_STYLE_COMPACT_VIEW)
+					->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS);
 			}
 			else {
-				$table = (new CTableInfo())
-					->setHeader(array_merge($header, [
-						make_sorting_header(_('Severity'), 'severity', $this->data['sort'], $this->data['sortorder'],
-							$link
-						),
-						$show_recovery_data
-							? (new CColHeader(_('Recovery time')))->addClass(ZBX_STYLE_CELL_WIDTH)
-							: null,
-						$show_recovery_data ? _('Status') : null,
-						_('Info'),
-						make_sorting_header(_('Host'), 'host', $this->data['sort'], $this->data['sortorder'], $link),
-						make_sorting_header(_('Problem'), 'name', $this->data['sort'], $this->data['sortorder'], $link),
-						($show_opdata == OPERATIONAL_DATA_SHOW_SEPARATELY)
-							? _('Operational data')
-							: null,
-						_('Duration'),
-						_('Update'),
-						_('Actions'),
-						$this->data['filter']['show_tags'] ? _('Tags') : null
-					]));
+				$table->setHeader(array_merge($header, [
+					make_sorting_header(_('Severity'), 'severity', $this->data['sort'], $this->data['sortorder'],
+						$link
+					),
+					$show_recovery_data
+						? (new CColHeader(_('Recovery time')))->addClass(ZBX_STYLE_CELL_WIDTH)
+						: null,
+					$show_recovery_data ? _('Status') : null,
+					_('Info'),
+					make_sorting_header(_('Host'), 'host', $this->data['sort'], $this->data['sortorder'], $link),
+					make_sorting_header(_('Problem'), 'name', $this->data['sort'], $this->data['sortorder'], $link),
+					($show_opdata == OPERATIONAL_DATA_SHOW_SEPARATELY)
+						? _('Operational data')
+						: null,
+					_('Duration'),
+					_('Update'),
+					_('Actions'),
+					$this->data['filter']['show_tags'] ? _('Tags') : null
+				]));
 			}
 
 			$tags = $this->data['filter']['show_tags']
@@ -1160,7 +1168,7 @@ class CScreenProblem extends CScreenBase {
 				]
 			], 'problem');
 
-			return $this->getOutput($form->addItem([$table, $paging, $footer]), false, $this->data);
+			return $this->getOutput($form->addItem([$table, $footer]), false, $this->data);
 		}
 
 		/*
@@ -1301,7 +1309,7 @@ class CScreenProblem extends CScreenBase {
 	 * @param array      $data['triggers']                      List of triggers.
 	 * @param int        $data['today']                         Timestamp of today's date.
 	 * @param array      $data['users']                         List of users.
-	 * @param array      $data['correlations']                  List of correlations.
+	 * @param array      $data['correlations']                  List of event correlations.
 	 * @param array      $data['dependencies']                  List of trigger dependencies.
 	 * @param array      $data['filter']                        Problem filter.
 	 * @param int        $data['filter']['show']                "Show" filter option.
@@ -1381,7 +1389,7 @@ class CScreenProblem extends CScreenBase {
 			$cell_status = new CSpan($value_str);
 
 			if (isEventUpdating($in_closing, $problem)) {
-				$cell_status->addClass('blink');
+				$cell_status->addClass('js-blink');
 			}
 
 			// Add colors and blinking to span depending on configuration and trigger parameters.
@@ -1398,10 +1406,10 @@ class CScreenProblem extends CScreenBase {
 				if ($problem['correlationid'] != 0) {
 					$info_icons[] = makeInformationIcon(
 						array_key_exists($problem['correlationid'], $data['correlations'])
-							? _s('Resolved by correlation rule "%1$s".',
+							? _s('Resolved by event correlation rule "%1$s".',
 								$data['correlations'][$problem['correlationid']]['name']
 							)
-							: _('Resolved by correlation rule.')
+							: _('Resolved by event correlation rule.')
 					);
 				}
 				elseif ($problem['userid'] != 0) {
@@ -1422,9 +1430,9 @@ class CScreenProblem extends CScreenBase {
 						? getUserFullname($data['users'][$unsuppression_action['userid']])
 						: _('Inaccessible user');
 
-					$info_icons[] = (new CSimpleButton())
-						->addClass(ZBX_STYLE_ACTION_ICON_UNSUPPRESS)
-						->addClass('blink')
+					$info_icons[] = (new CButtonIcon(ZBX_ICON_EYE))
+						->addClass(ZBX_STYLE_COLOR_ICON)
+						->addClass('js-blink')
 						->setHint(_s('Unsuppressed by: %1$s', $user_unsuppressed));
 				}
 				elseif ($problem['suppression_data']) {
@@ -1442,10 +1450,7 @@ class CScreenProblem extends CScreenBase {
 			}
 
 			if ($data['filter']['compact_view'] && $data['filter']['show_suppressed'] && count($info_icons) > 1) {
-				$cell_info = (new CButton(null))
-					->addClass(ZBX_STYLE_ICON_WIZARD_ACTION)
-					->addStyle('margin-left: -3px;')
-					->setHint(makeInformationList($info_icons));
+				$cell_info = (new CButtonIcon(ZBX_ICON_MORE))->setHint(makeInformationList($info_icons));
 			}
 			else {
 				$cell_info = makeInformationList($info_icons);
@@ -1515,9 +1520,7 @@ class CScreenProblem extends CScreenBase {
 
 			$checkbox_col = new CCol(new CCheckBox('eventids['.$problem['eventid'].']', $problem['eventid']));
 			$empty_col = new CCol();
-			$symptom_col = (new CCol(
-				makeActionIcon(['icon' => ZBX_STYLE_ACTION_ICON_SYMPTOM, 'title' => _('Symptom')])
-			));
+			$symptom_col = (new CCol(new CIcon(ZBX_ICON_ARROW_TOP_RIGHT, _('Symptom'))));
 
 			if ($data['show_timeline']) {
 				$checkbox_col->addClass(ZBX_STYLE_PROBLEM_EXPAND_TD);
@@ -1533,8 +1536,8 @@ class CScreenProblem extends CScreenBase {
 				if ($problem['symptom_count'] > 0) {
 					// Show symptom counter and collapse/expand button.
 					$symptom_count_span = (new CSpan($problem['symptom_count']))
-						->addClass(ZBX_STYLE_TAG)
-						->addStyle('max-width: 22px;');
+						->addClass(ZBX_STYLE_ENTITY_COUNT)
+						->addStyle('max-width: 3ch;');
 
 					if ($problem['symptom_count'] >= 1000) {
 						$symptom_count_span->setHint($problem['symptom_count']);
@@ -1542,13 +1545,12 @@ class CScreenProblem extends CScreenBase {
 
 					$symptom_count_col = (new CCol($symptom_count_span))->addClass(ZBX_STYLE_SECOND_COL);
 
-					$collapse_expand_col = (new CCol(
-						(new CButton(null))
+					$collapse_expand_col = new CCol(
+						(new CButtonIcon(ZBX_ICON_CHEVRON_DOWN, _('Expand')))
+							->addClass(ZBX_STYLE_COLLAPSED)
 							->setAttribute('data-eventid', $problem['eventid'])
 							->setAttribute('data-action', 'show_symptoms')
-							->addClass(ZBX_STYLE_BTN_WIDGET_EXPAND)
-							->setTitle(_('Expand'))
-					))->addClass(ZBX_STYLE_THIRD_COL);
+					);
 
 					if ($data['show_timeline']) {
 						$symptom_count_col->addClass(ZBX_STYLE_PROBLEM_EXPAND_TD);
@@ -1571,7 +1573,7 @@ class CScreenProblem extends CScreenBase {
 							->addClass('problem-row')
 							->addItem([
 								$empty_col->addClass(ZBX_STYLE_SECOND_COL),
-								$empty_col->addClass(ZBX_STYLE_THIRD_COL)
+								$empty_col
 							]);
 					}
 					elseif ($data['show_two_columns']) {
@@ -1599,7 +1601,7 @@ class CScreenProblem extends CScreenBase {
 					$row = (new CRow([
 						$empty_col,
 						$checkbox_col,
-						$symptom_col->addClass(ZBX_STYLE_THIRD_COL)
+						$symptom_col
 					]))
 						->addClass(ZBX_STYLE_PROBLEM_NESTED)
 						->addClass(ZBX_STYLE_PROBLEM_NESTED_SMALL)
@@ -1620,9 +1622,7 @@ class CScreenProblem extends CScreenBase {
 				 * column.
 				 */
 				if (!$nested && $data['show_three_columns']) {
-					$row->addItem(
-						$empty_col->addClass(ZBX_STYLE_THIRD_COL)
-					);
+					$row->addItem($empty_col);
 				}
 			}
 
@@ -1635,8 +1635,8 @@ class CScreenProblem extends CScreenBase {
 				$row->addItem([
 					$cell_clock->addClass(ZBX_STYLE_TIMELINE_DATE),
 					(new CCol())
-							->addClass(ZBX_STYLE_TIMELINE_AXIS)
-							->addClass(ZBX_STYLE_TIMELINE_DOT),
+						->addClass(ZBX_STYLE_TIMELINE_AXIS)
+						->addClass(ZBX_STYLE_TIMELINE_DOT),
 					(new CCol())->addClass(ZBX_STYLE_TIMELINE_TD)
 				]);
 			}
@@ -1718,9 +1718,7 @@ class CScreenProblem extends CScreenBase {
 						_s('Displaying %1$s of %2$s found', ZBX_PROBLEM_SYMPTOM_LIMIT, $problem['symptom_count'])
 					))->addClass(ZBX_STYLE_TABLE_STATS)
 				))->addClass(ZBX_STYLE_PAGING_BTN_CONTAINER)
-			))
-				->addClass(ZBX_STYLE_PROBLEM_NESTED_SMALL)
-				->addClass(ZBX_STYLE_SYMPTOM_LIMIT_TD);
+			))->addClass(ZBX_STYLE_PROBLEM_NESTED_SMALL);
 
 			if ($data['show_timeline']) {
 				$colspan = 1;
@@ -1735,9 +1733,7 @@ class CScreenProblem extends CScreenBase {
 					$colspan++;
 				}
 
-				$empty_col = (new CCol())
-					->addClass(ZBX_STYLE_PROBLEM_EXPAND_TD)
-					->addClass(ZBX_STYLE_SYMPTOM_LIMIT_TD);
+				$empty_col = (new CCol())->addClass(ZBX_STYLE_PROBLEM_EXPAND_TD);
 
 				if ($colspan > 1) {
 					$empty_col->setColSpan($colspan);
@@ -1745,12 +1741,8 @@ class CScreenProblem extends CScreenBase {
 
 				$row->addItem([
 					$empty_col,
-					(new CCol())
-						->addClass(ZBX_STYLE_TIMELINE_AXIS)
-						->addClass(ZBX_STYLE_SYMPTOM_LIMIT_TD),
-					(new CCol())
-						->addClass(ZBX_STYLE_TIMELINE_TD)
-						->addClass(ZBX_STYLE_SYMPTOM_LIMIT_TD),
+					(new CCol())->addClass(ZBX_STYLE_TIMELINE_AXIS),
+					(new CCol())->addClass(ZBX_STYLE_TIMELINE_TD),
 					$symptom_limit_col->setColSpan($table->getNumCols() - $colspan - 2)
 				]);
 			}
@@ -1787,9 +1779,12 @@ class CScreenProblem extends CScreenBase {
 		foreach ($items as $itemid => $item) {
 			if (array_key_exists($itemid, $history_values)) {
 				$last_value = reset($history_values[$itemid]);
-				$last_value['value'] = formatHistoryValue(str_replace(["\r\n", "\n"], [" "], $last_value['value']),
-					$item
-				);
+
+				if ($item['value_type'] != ITEM_VALUE_TYPE_BINARY) {
+					$last_value['value'] = formatHistoryValue(str_replace(["\r\n", "\n"], [" "], $last_value['value']),
+						$item
+					);
+				}
 			}
 			else {
 				$last_value = [
@@ -1808,7 +1803,10 @@ class CScreenProblem extends CScreenBase {
 							? zbx_date2str(DATE_TIME_FORMAT_SECONDS, $last_value['clock'])
 							: UNRESOLVED_MACRO_STRING
 					),
-					new CCol($last_value['value']),
+					new CCol($item['value_type'] == ITEM_VALUE_TYPE_BINARY
+						? italic(_('binary value'))->addClass(ZBX_STYLE_GREY)
+						: $last_value['value']
+					),
 					new CCol(
 						($item['value_type'] == ITEM_VALUE_TYPE_FLOAT || $item['value_type'] == ITEM_VALUE_TYPE_UINT64)
 							? (CWebUser::checkAccess(CRoleHelper::UI_MONITORING_LATEST_DATA)
@@ -1828,13 +1826,19 @@ class CScreenProblem extends CScreenBase {
 					)
 				]);
 
-				$latest_values[] = (new CLinkAction($last_value['value']))
+				$latest_values[] = (new CLinkAction(
+					$item['value_type'] == ITEM_VALUE_TYPE_BINARY
+						? _('binary value')
+						: $last_value['value']
+				))
 					->addClass('hint-item')
 					->setAttribute('data-hintbox', '1');
 				$latest_values[] = ', ';
 			}
 			else {
-				$latest_values[] = $last_value['value'];
+				$latest_values[] = $item['value_type'] == ITEM_VALUE_TYPE_BINARY
+					? UNRESOLVED_MACRO_STRING
+					: $last_value['value'];
 			}
 		}
 
