@@ -1,21 +1,16 @@
-<?php declare(strict_types = 1);
+<?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -56,6 +51,13 @@ class CExpressionValidator extends CValidator {
 	 */
 	private $math_function_parameters = [];
 
+	/**
+	 * Known math functions along with additional requirements for usage in expressions.
+	 *
+	 * @var array
+	 */
+	private $math_function_expression_rules = [];
+
 	/**
 	 * Provider of information on history functions.
 	 *
@@ -70,17 +72,26 @@ class CExpressionValidator extends CValidator {
 	 */
 	private $hist_function_parameters = [];
 
+	/**
+	 * Known history functions along with additional requirements for usage in expressions.
+	 *
+	 * @var array
+	 */
+	private $hist_function_expression_rules = [];
+
 	/**
 	 * @param array $options
 	 */
 	public function __construct(array $options = []) {
 		$this->options = $options + $this->options;
 
-		$this->math_function_data = new CMathFunctionData();
+		$this->math_function_data = new CMathFunctionData(['calculated' => $this->options['calculated']]);
 		$this->math_function_parameters = $this->math_function_data->getParameters();
+		$this->math_function_expression_rules = $this->math_function_data->getExpressionRules();
 
 		$this->hist_function_data = new CHistFunctionData(['calculated' => $this->options['calculated']]);
 		$this->hist_function_parameters = $this->hist_function_data->getParameters();
+		$this->hist_function_expression_rules = $this->hist_function_data->getExpressionRules();
 	}
 
 	/**
@@ -91,7 +102,7 @@ class CExpressionValidator extends CValidator {
 	 * @return bool
 	 */
 	public function validate($tokens) {
-		if (!$this->validateRecursively($tokens, null)) {
+		if (!$this->validateRecursively($tokens, null, null)) {
 			return false;
 		}
 
@@ -109,12 +120,13 @@ class CExpressionValidator extends CValidator {
 	/**
 	 * Validate expression (recursive helper).
 	 *
-	 * @param array $tokens             A hierarchy of tokens.
+	 * @param array      $tokens        A hierarchy of tokens.
 	 * @param array|null $parent_token  Parent token containing the hierarchy of tokens.
+	 * @param int|null   $position      The parameter number in the math function.
 	 *
 	 * @return bool
 	 */
-	private function validateRecursively(array $tokens, ?array $parent_token): bool {
+	private function validateRecursively(array $tokens, ?array $parent_token, ?int $position): bool {
 		foreach ($tokens as $token) {
 			switch ($token['type']) {
 				case CExpressionParserResult::TOKEN_TYPE_MATH_FUNCTION:
@@ -135,8 +147,14 @@ class CExpressionValidator extends CValidator {
 						return false;
 					}
 
-					foreach ($token['data']['parameters'] as $parameter) {
-						if (!$this->validateRecursively($parameter['data']['tokens'], $token)) {
+					if (!$this->validateMathFunctionExpressionRules($token)) {
+						$this->setError(_s('incorrect usage of function "%1$s"', $token['data']['function']));
+
+						return false;
+					}
+
+					foreach ($token['data']['parameters'] as $position => $parameter) {
+						if (!$this->validateRecursively($parameter['data']['tokens'], $token, $position)) {
 							return false;
 						}
 					}
@@ -159,7 +177,7 @@ class CExpressionValidator extends CValidator {
 					];
 
 					if ($this->options['calculated']) {
-						$options['aggregating'] = CHistFunctionData::isAggregating($token['data']['function']);
+						$options['aggregating'] = $this->hist_function_data->isAggregating($token['data']['function']);
 					}
 
 					$hist_function_validator = new CHistFunctionValidator($options);
@@ -170,22 +188,9 @@ class CExpressionValidator extends CValidator {
 						return false;
 					}
 
-					if ($options['calculated'] && $options['aggregating']) {
-						if ($parent_token === null
-								|| $parent_token['type'] != CExpressionParserResult::TOKEN_TYPE_MATH_FUNCTION
-								|| !CMathFunctionData::isAggregating($parent_token['data']['function'])
-								|| count($parent_token['data']['parameters']) != 1
-								|| count($parent_token['data']['parameters'][0]['data']['tokens']) != 1) {
-							$this->setError(_s('incorrect usage of function "%1$s"', $token['data']['function']));
+					if (!$this->validateHistFunctionExpressionRules($token, $parent_token, $position)) {
+						$this->setError(_s('incorrect usage of function "%1$s"', $token['data']['function']));
 
-							return false;
-						}
-					}
-
-					break;
-
-				case CExpressionParserResult::TOKEN_TYPE_EXPRESSION:
-					if (!$this->validateRecursively($token['data']['tokens'], null)) {
 						return false;
 					}
 
@@ -196,6 +201,134 @@ class CExpressionValidator extends CValidator {
 		return true;
 	}
 
+	/**
+	 * @param array $token
+	 *
+	 * @return bool
+	 */
+	private function validateMathFunctionExpressionRules(array $token): bool {
+		if (!array_key_exists($token['data']['function'], $this->math_function_expression_rules)) {
+			return true;
+		}
+
+		foreach ($this->math_function_expression_rules[$token['data']['function']] as $rule_set) {
+			if (array_key_exists('if', $rule_set)) {
+				if (array_key_exists('parameters', $rule_set['if'])) {
+					if (array_key_exists('count', $rule_set['if']['parameters'])
+							&& count($token['data']['parameters']) != $rule_set['if']['parameters']['count']) {
+						continue;
+					}
+
+					if (array_key_exists('min', $rule_set['if']['parameters'])
+							&& count($token['data']['parameters']) < $rule_set['if']['parameters']['min']) {
+						continue;
+					}
+
+					if (array_key_exists('max', $rule_set['if']['parameters'])
+							&& count($token['data']['parameters']) > $rule_set['if']['parameters']['max']) {
+						continue;
+					}
+				}
+			}
+
+			foreach ($rule_set['rules'] as $rule) {
+				switch ($rule['type']) {
+					case 'require_history_child':
+						$tokens = $token['data']['parameters'][$rule['position']]['data']['tokens'];
+
+						if (count($tokens) != 1
+								|| $tokens[0]['type'] != CExpressionParserResult::TOKEN_TYPE_HIST_FUNCTION) {
+							return false;
+						}
+
+						if (array_key_exists('in', $rule) && !in_array($tokens[0]['data']['function'], $rule['in'])) {
+							return false;
+						}
+
+						break;
+
+					case 'regexp':
+						$tokens = $token['data']['parameters'][$rule['position']]['data']['tokens'];
+
+						if (preg_match($rule['pattern'], CHistFunctionParser::unquoteParam($tokens[0]['match'])) != 1) {
+							return false;
+						}
+
+						break;
+
+					default:
+						return false;
+				}
+			}
+		}
+
+		return true;
+	}
+
+	/**
+	 * @param array      $token
+	 * @param array|null $parent_token
+	 * @param int|null   $position
+	 *
+	 * @return bool
+	 */
+	private function validateHistFunctionExpressionRules(array $token, ?array $parent_token, ?int $position): bool {
+		if (!array_key_exists($token['data']['function'], $this->hist_function_expression_rules)) {
+			return true;
+		}
+
+		$is_valid = true;
+
+		foreach ($this->hist_function_expression_rules[$token['data']['function']] as $rule) {
+			switch ($rule['type']) {
+				case 'require_math_parent':
+					if ($parent_token === null
+							|| $parent_token['type'] != CExpressionParserResult::TOKEN_TYPE_MATH_FUNCTION) {
+						$is_valid = false;
+						break;
+					}
+
+					if (array_key_exists('in', $rule) && !in_array($parent_token['data']['function'], $rule['in'])) {
+						$is_valid = false;
+						break;
+					}
+
+					if (array_key_exists('parameters', $rule)) {
+						if (array_key_exists('count', $rule['parameters'])
+								&& count($parent_token['data']['parameters']) != $rule['parameters']['count']) {
+							$is_valid = false;
+							break;
+						}
+
+						if (array_key_exists('min', $rule['parameters'])
+								&& count($parent_token['data']['parameters']) < $rule['parameters']['min']) {
+							$is_valid = false;
+							break;
+						}
+
+						if (array_key_exists('max', $rule['parameters'])
+								&& count($parent_token['data']['parameters']) > $rule['parameters']['max']) {
+							$is_valid = false;
+							break;
+						}
+					}
+
+					if (array_key_exists('position', $rule) && $position != $rule['position']) {
+						$is_valid = false;
+						break;
+					}
+
+					return true;
+
+				default:
+					$is_valid = false;
+					break;
+			}
+		}
+
+		return $is_valid;
+	}
+
 	/**
 	 * Check if there are history function tokens within the hierarchy of given tokens.
 	 *
