@@ -1,38 +1,18 @@
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
-const KEY_ARROW_DOWN = 40;
-const KEY_ARROW_LEFT = 37;
-const KEY_ARROW_RIGHT = 39;
-const KEY_ARROW_UP = 38;
-const KEY_BACKSPACE = 8;
-const KEY_DELETE = 46;
-const KEY_ENTER = 13;
-const KEY_ESCAPE = 27;
-const KEY_TAB = 9;
-const KEY_PAGE_UP = 33;
-const KEY_PAGE_DOWN = 34;
-const KEY_END = 35;
-const KEY_HOME = 36;
-const KEY_SPACE = 32;
-
 /**
  * jQuery based publish/subscribe handler.
  *
@@ -385,17 +365,19 @@ function PopUp(action, parameters, {
 						buttons.push({
 							'title': t('Ok'),
 							'cancel': true,
-							'action': (typeof resp.cancel_action !== 'undefined') ? resp.cancel_action : function() {}
+							'action': (resp.cancel_action !== undefined) ? resp.cancel_action : () => {}
 						});
 						break;
 
 					default:
-						buttons.push({
-							'title': t('Cancel'),
-							'class': 'btn-alt js-cancel',
-							'cancel': true,
-							'action': (typeof resp.cancel_action !== 'undefined') ? resp.cancel_action : function() {}
-						});
+						if (!buttons.some(button => button.cancel)) {
+							buttons.push({
+								'title': t('Cancel'),
+								'class': 'btn-alt js-cancel',
+								'cancel': true,
+								'action': (resp.cancel_action !== undefined) ? resp.cancel_action : () => {}
+							});
+						}
 				}
 
 				overlay.setProperties({
@@ -408,30 +390,55 @@ function PopUp(action, parameters, {
 					script_inline: resp.script_inline,
 					data: resp.data || null
 				});
+
+				const resizeHandler = (grid) => {
+					for (const label of grid.querySelectorAll(':scope > label')) {
+						const rect = label.getBoundingClientRect()
+
+						if (rect.width > 0) {
+							// Use of setTimeout() to prevent ResizeObserver observation error in Safari.
+							setTimeout(() => {
+								grid.style.setProperty('--label-width', `${Math.round(rect.width)}px`);
+							});
+							break;
+						}
+					}
+				}
+
+				for (const grid of overlay.$dialogue.$body[0].querySelectorAll(`form .${ZBX_STYLE_FORM_GRID}`)) {
+					new ResizeObserver(() => resizeHandler(grid)).observe(grid);
+
+					const labels = grid.querySelectorAll(`:scope > label, :scope > .${ZBX_STYLE_COLLAPSIBLE} > label`);
+					for (const label of labels) {
+						new MutationObserver(() => resizeHandler(grid)).observe(label, {childList: true});
+					}
+				}
 			}
 
 			overlay.recoverFocus();
 			overlay.containFocus();
 		})
 		.fail((resp) => {
-			const error = resp.responseJSON !== undefined && resp.responseJSON.error !== undefined
-				? resp.responseJSON.error
-				: {title: t('Unexpected server error.')};
+			if (resp.statusText !== 'abort') {
+				const error = resp.responseJSON !== undefined && resp.responseJSON.error !== undefined
+					? resp.responseJSON.error
+					: {title: t('Unexpected server error.')};
 
-			overlay.setProperties({
-				content: makeMessageBox('bad', error.messages, error.title, false),
-				buttons: [
-					{
-						'title': t('Cancel'),
-						'class': 'btn-alt js-cancel',
-						'cancel': true,
-						'action': function() {}
-					}
-				]
-			});
+				overlay.setProperties({
+					content: makeMessageBox('bad', error.messages, error.title, false),
+					buttons: [
+						{
+							'title': t('Cancel'),
+							'class': 'btn-alt js-cancel',
+							'cancel': true,
+							'action': function() {}
+						}
+					]
+				});
 
-			overlay.recoverFocus();
-			overlay.containFocus();
+				overlay.recoverFocus();
+				overlay.containFocus();
+			}
 		});
 
 	addToOverlaysStack(overlay);
@@ -465,7 +472,7 @@ function acknowledgePopUp(parameters, trigger_element) {
 		history.replaceState({}, '', url.getUrl());
 	});
 
-	overlay.$dialogue[0].addEventListener('overlay.close', () => {
+	overlay.$dialogue[0].addEventListener('dialogue.close', () => {
 		history.replaceState({}, '', backurl);
 	}, {once: true});
 
@@ -746,14 +753,16 @@ function validate_trigger_expression(overlay) {
 				? jQuery(form).find('#' + ret.dstfld1).get(0)
 				: document.getElementById(ret.dstfld1);
 
-			if (ret.dstfld1 === 'expression' || ret.dstfld1 === 'recovery_expression') {
-				jQuery(obj).val(jQuery(obj).val() + ret.expression);
+			if ((ret.dstfld1 === 'expr_temp' || ret.dstfld1 === 'recovery_expr_temp')) {
+				jQuery(obj).val(ret.expression);
 			}
 			else {
-				jQuery(obj).val(ret.expression);
+				jQuery(obj).val(jQuery(obj).val() + ret.expression);
 			}
 
 			overlayDialogueDestroy(overlay.dialogueid);
+
+			obj.dispatchEvent(new Event('change'));
 		},
 		dataType: 'json',
 		type: 'POST'
@@ -1042,17 +1051,17 @@ function openMassupdatePopup(action, parameters = {}, {
 	}
 
 	switch (action) {
-		case 'popup.massupdate.item':
+		case 'item.massupdate':
 			parameters.context = form.querySelector('#form_context').value;
 			parameters.prototype = 0;
 			break;
 
-		case 'popup.massupdate.trigger':
+		case 'trigger.massupdate':
 			parameters.context = form.querySelector('#form_context').value;
 			break;
 
-		case 'popup.massupdate.itemprototype':
-		case 'popup.massupdate.triggerprototype':
+		case 'item.prototype.massupdate':
+		case 'trigger.prototype.massupdate':
 			parameters.parent_discoveryid = form.querySelector('#form_parent_discoveryid').value;
 			parameters.context = form.querySelector('#form_context').value;
 			parameters.prototype = 1;
@@ -1083,6 +1092,7 @@ function visibilityStatusChanges(value, objectid, replace_to) {
 		}
 		else if (!value) {
 			const new_obj = document.createElement('span');
+			new_obj.classList.add('visibility-box-caption');
 			new_obj.setAttribute('id', obj.id);
 			new_obj.innerHTML = replace_to;
 			new_obj.originalObject = obj;
