@@ -1,21 +1,16 @@
 /*
- ** Zabbix
- ** Copyright (C) 2001-2023 Zabbix SIA
- **
- ** This program is free software; you can redistribute it and/or modify
- ** it under the terms of the GNU General Public License as published by
- ** the Free Software Foundation; either version 2 of the License, or
- ** (at your option) any later version.
- **
- ** This program is distributed in the hope that it will be useful,
- ** but WITHOUT ANY WARRANTY; without even the implied warranty of
- ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- ** GNU General Public License for more details.
- **
- ** You should have received a copy of the GNU General Public License
- ** along with this program; if not, write to the Free Software
- ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- **/
+** Copyright (C) 2001-2024 Zabbix SIA
+**
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
+**
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
+**
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
+**/
 
 
 /**
@@ -71,7 +66,7 @@ jQuery(function($) {
 	if ($search.length) {
 		createSuggest('search');
 
-		var $search_icon = $search.siblings('.search-icon');
+		var $search_icon = $search.siblings('.js-search');
 
 		$search.on('keyup', function() {
 			$search_icon.prop('disabled', $.trim($search.val()) === '');
@@ -168,6 +163,10 @@ jQuery(function($) {
 				sections = getMenuPopupSubmenu(data);
 				break;
 
+			case 'drule':
+				sections = getMenuPopupDRule(data);
+				break;
+
 			default:
 				return;
 		}
@@ -391,6 +390,10 @@ jQuery(function($) {
 		var confirmation = button.attr('data-confirmation');
 
 		if (typeof confirmation === 'undefined' || (typeof confirmation !== 'undefined' && confirm(confirmation))) {
+			if (button.attr('data-post')) {
+				return redirect(button.attr('data-url'), 'post', '_csrf_token', true);
+			}
+
 			window.location = button.attr('data-url');
 		}
 	});
