@@ -1,45 +1,48 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
+require_once dirname(__FILE__).'/include/defines.inc.php';
 
 // get language translations
 require_once dirname(__FILE__).'/include/locales.inc.php';
 require_once dirname(__FILE__).'/include/gettextwrapper.inc.php';
 
-setupLocale(array_key_exists('lang', $_GET) ? (string) $_GET['lang'] : 'en_GB');
+setupLocale(array_key_exists('lang', $_GET) ? (string) $_GET['lang'] : ZBX_DEFAULT_LANG);
 
 require_once dirname(__FILE__).'/include/js.inc.php';
-
-require_once dirname(__FILE__).'/include/defines.inc.php';
 require_once dirname(__FILE__).'/include/classes/helpers/CCookieHelper.php';
 
 // available scripts 'scriptFileName' => 'path relative to js/'
 $available_js = [
+	'defines.js' => '',
 	'common.js' => '',
 	'class.dashboard.js' => '',
 	'class.dashboard.page.js' => '',
+	'class.dashboard.print.js' => '',
 	'class.dashboard.widget.placeholder.js' => '',
+	'class.widgets-data.js' => '',
+	'class.widget-base.js' => '',
 	'class.widget.js' => '',
 	'class.widget.inaccessible.js' => '',
 	'class.widget.iterator.js' => '',
+	'class.widget.misconfigured.js' => '',
 	'class.widget.paste-placeholder.js' => '',
+	'class.widget-field.checkbox-list.js' => '',
+	'class.widget-field.multiselect.js' => '',
+	'class.widget-field.time-period.js' => '',
+	'class.widget-select.popup.js' => '',
 	'hostinterfacemanager.js' => '',
 	'hostmacrosmanager.js' => '',
 	'menupopup.js' => '',
@@ -58,15 +61,17 @@ $available_js = [
 	'inputsecret.js' => '',
 	'macrovalue.js' => '',
 	// vendors
-	'jquery.js' => 'vendors/',
-	'jquery-ui.js' => 'vendors/',
-	'leaflet.js' => 'vendors/Leaflet/Leaflet/',
-	'leaflet.markercluster.js' => 'vendors/Leaflet/Leaflet.markercluster/',
+	'jquery.js' => 'vendors/jQuery/',
+	'jquery-ui.js' => 'vendors/jQueryUI/',
+	'leaflet.js' => 'vendors/Leaflet/',
+	'leaflet.markercluster.js' => 'vendors/Leaflet.markercluster/',
+	'd3.js' => 'vendors/D3/',
+	'qrcode.js' => 'vendors/qrcode/',
 	// classes
 	'component.z-bar-gauge.js' => '',
 	'component.z-select.js' => '',
+	'class.event-hub.js' => '',
 	'class.base-component.js' => '',
-	'class.bbcode.js' => '',
 	'class.calendar.js' => '',
 	'class.cdate.js' => '',
 	'class.cdebug.js' => '',
@@ -88,11 +93,14 @@ $available_js = [
 	'class.csuggest.js' => '',
 	'class.csvggraph.js' => '',
 	'class.curl.js' => '',
+	'class.form.fieldset.collapsible.js' => '',
 	'class.overlaycollection.js' => '',
 	'class.overlay.js' => '',
 	'class.cverticalaccordion.js' => '',
+	'class.script.js' => '',
 	'class.scrollable.js' => '',
 	'class.sidebar.js' => '',
+	'class.software-version-check.js' => '',
 	'class.sortable.js' => '',
 	'class.svg.canvas.js' => 'vector/',
 	'class.svg.map.js' => 'vector/',
@@ -102,6 +110,7 @@ $available_js = [
 	'class.tabfilteritem.js' => '',
 	'class.tagfilteritem.js' => '',
 	'class.template.js' => '',
+	'class.navigationtree.js' => '',
 	'init.js' => '',
 	'class.tab-indicators.js' => '',
 	// templates
@@ -115,10 +124,9 @@ $available_js = [
 
 $translate_strings = [
 	'gtlc.js' => [
-		'S_MINUTE_SHORT' => _x('m', 'minute short')
-	],
-	'class.overlay.js' => [
-		'Operation details' => _('Operation details')
+		'S_MINUTE_SHORT' => _x('m', 'minute short'),
+		'Failed to update time selector.' => _('Failed to update time selector.'),
+		'Unexpected server error.' => _('Unexpected server error.')
 	],
 	'class.dashboard.js' => [
 		'Actions' => _('Actions'),
@@ -152,34 +160,55 @@ $translate_strings = [
 	'class.geomaps.js' => [
 		'Severity filter' => _('Severity filter')
 	],
-	'class.widget.js' => [
+	'class.widget-base.js' => [
 		'10 seconds' => _n('%1$s second', '%1$s seconds', 10),
 		'30 seconds' => _n('%1$s second', '%1$s seconds', 30),
 		'1 minute' => _n('%1$s minute', '%1$s minutes', 1),
 		'2 minutes' => _n('%1$s minute', '%1$s minutes', 2),
 		'10 minutes' => _n('%1$s minute', '%1$s minutes', 10),
 		'15 minutes' => _n('%1$s minute', '%1$s minutes', 15),
-		'Actions' => _s('Actions'),
-		'Copy' => _s('Copy'),
-		'Delete' => _s('Delete'),
-		'Edit' => _s('Edit'),
+		'Actions' => _('Actions'),
+		'Copy' => _('Copy'),
+		'Delete' => _('Delete'),
+		'Edit' => _('Edit'),
 		'No refresh' => _('No refresh'),
-		'Paste' => _s('Paste'),
-		'Refresh interval' => _s('Refresh interval')
+		'Paste' => _('Paste'),
+		'Refresh interval' => _('Refresh interval')
 	],
 	'class.widget.inaccessible.js' => [
-		'Actions' => _s('Actions'),
-		'Copy' => _s('Copy'),
-		'Inaccessible widget' => _('Inaccessible widget'),
-		'Refresh interval' => _s('Refresh interval')
+		'No permissions to referred object or it does not exist!' =>
+			_('No permissions to referred object or it does not exist!'),
+		'Refresh interval' => _('Refresh interval')
 	],
 	'class.widget.iterator.js' => [
-		'Next page' => _s('Next page'),
-		'Previous page' => _s('Previous page'),
+		'Next page' => _('Next page'),
+		'Previous page' => _('Previous page'),
 		'Widget is too small for the specified number of columns and rows.' =>
-			_s('Widget is too small for the specified number of columns and rows.')
+			_('Widget is too small for the specified number of columns and rows.')
+	],
+	'class.widget.misconfigured.js' => [
+		'Please update configuration' => _('Please update configuration'),
+		'Referred widget is unavailable' => _('Referred widget is unavailable'),
+		'Refresh interval' => _('Refresh interval')
+	],
+	'class.widget-select.popup.js' => [
+		'Name' => _('Name'),
+		'No compatible widgets.' => _('No compatible widgets.'),
+		'Widget' => _('Widget')
+	],
+	'class.widget-field.multiselect.js' => [
+		'Dashboard' => _('Dashboard'),
+		'Widget' => _('Widget'),
+		'Unavailable widget' => _('Unavailable widget'),
+		'Dashboard is used as data source.' => _('Dashboard is used as data source.'),
+		'Another widget is used as data source.' => _('Another widget is used as data source.')
+	],
+	'class.widget-field.time-period.js' => [
+		'Unavailable widget' => _('Unavailable widget')
 	],
 	'functions.js' => [
+		'Error' => _('Error'),
+		'Ok' => _('Ok'),
 		'Cancel' => _('Cancel'),
 		'S_CLOSE' => _('Close'),
 		'Execute' => _('Execute'),
@@ -258,14 +287,14 @@ $translate_strings = [
 		'S_COLOR_IS_NOT_CORRECT' => _('Color "%1$s" is not correct: expecting hexadecimal color code (6 symbols).')
 	],
 	'class.notifications.js' => [
+		'Mute for %1$s' => _('Mute for %1$s'),
 		'S_PROBLEM_ON' => _('Problem on'),
 		'S_RESOLVED' => _('Resolved'),
-		'S_MUTE' => _('Mute'),
 		'S_CANNOT_SUPPORT_NOTIFICATION_AUDIO' => _('Cannot support notification audio for this device.'),
-		'S_UNMUTE' => _('Unmute'),
 		'S_CLOSE' => _('Close'),
-		'S_SNOOZE' => _('Snooze'),
-		'Unexpected server error.' => _('Unexpected server error.')
+		'Snooze for %1$s' => _('Snooze for %1$s'),
+		'Unexpected server error.' => _('Unexpected server error.'),
+		'Unmute for %1$s' => _('Unmute for %1$s')
 	],
 	'class.cookie.js' => [
 		'S_MAX_COOKIE_SIZE_REACHED' => _('We are sorry, the maximum possible number of elements to remember has been reached.')
@@ -334,6 +363,7 @@ $translate_strings = [
 		'Delete' => _('Delete'),
 		'Delete dashboard?' => _('Delete dashboard?'),
 		'Discovery' => _('Discovery'),
+		'Discovery rule' => _('Discovery rule'),
 		'Do you wish to replace the conditional expression?' => _('Do you wish to replace the conditional expression?'),
 		'Execute now' => _('Execute now'),
 		'Item' => _('Item'),
@@ -367,7 +397,8 @@ $translate_strings = [
 		'Values' => _('Values'),
 		'View' => _('View'),
 		'Web' => _('Web'),
-		'S_SELECTED_SR' => _x('%1$s, selected', 'screen reader')
+		'S_SELECTED_SR' => _x('%1$s, selected', 'screen reader'),
+		'Unexpected server error.' => _('Unexpected server error.')
 	],
 	'init.js' => [
 		'Debug' => _('Debug'),
@@ -387,10 +418,17 @@ $translate_strings = [
 		'S_DISPLAYING_FOUND' => _('Displaying %1$s of %2$s found'),
 		'S_MINUTE_SHORT' => _x('m', 'minute short')
 	],
+	'class.csvggauge.js' => [
+		'No data' => _('No data')
+	],
+	'class.svghoneycomb.js' => [
+		'No data' => _('No data')
+	],
 	'common.js' => [
 		'Cancel' => _('Cancel'),
 		'Ok' => _('Ok'),
-		'Unexpected server error.' => _('Unexpected server error.')
+		'Unexpected server error.' => _('Unexpected server error.'),
+		'Any changes made in the current form will be lost.' => _('Any changes made in the current form will be lost.')
 	],
 	'component.z-select.js' => [
 		'All' => _('All')
@@ -398,17 +436,34 @@ $translate_strings = [
 	'macrovalue.js' => [
 		'Set new value' => _('Set new value'),
 		'value' => _('value')
+	],
+	'class.script.js' => [
+		'Cancel' => _('Cancel'),
+		'Cannot open URL' => _('Cannot open URL'),
+		'Execute' => _('Execute'),
+		'Execution confirmation' => _('Execution confirmation'),
+		'Invalid URL: %1$s' => _('Invalid URL: %1$s'),
+		'Open URL' => _('Open URL'),
+		'Unexpected server error.' => _('Unexpected server error.'),
+		'URL opening confirmation' => _('URL opening confirmation')
+	],
+	'class.navigationtree.js' => [
+		'Maintenance with data collection' => _('Maintenance with data collection'),
+		'Maintenance without data collection' => _('Maintenance without data collection')
 	]
 ];
 
 $js = '';
 if (empty($_GET['files'])) {
 	$files = [
+		'defines.js',
 		'jquery.js',
 		'jquery-ui.js',
+		'main.js',
 		'common.js',
 		'component.z-bar-gauge.js',
 		'component.z-select.js',
+		'class.event-hub.js',
 		'class.base-component.js',
 		'class.cdebug.js',
 		'class.overlaycollection.js',
@@ -419,12 +474,13 @@ if (empty($_GET['files'])) {
 		'class.menu.js',
 		'class.menu-item.js',
 		'class.rpc.js',
-		'class.bbcode.js',
 		'class.csuggest.js',
+		'class.script.js',
 		'class.scrollable.js',
 		'class.sidebar.js',
+		'class.sortable.js',
 		'class.template.js',
-		'main.js',
+		'class.navigationtree.js',
 		'chkbxrange.js',
 		'functions.js',
 		'menupopup.js',
